# -*- coding: utf-8 -*-

"""Top-level package for postalcodes-ni."""
from postalcodes_ni.postalcodes import (
    get_all_municipalities_by_iso, get_all_municipalities_by_postal,
    get_municipality_by_name, get_municipality_by_postal
)
__all__ = [
    'get_all_municipalities_by_iso',
    'get_all_municipalities_by_postal',
    'get_municipality_by_name',
    'get_municipality_by_postal'
]

__author__ = """Oscar Cortez"""
__email__ = 'om.cortez.2010@gmail.com'
__version__ = '1.1.1'



_postal_codes = {
    "MN": [
        {"name": "Managua", "code": 10000, "neighborhood": "master"},
        {
            "name": "Managua",
            "code": 11001,
            "neighborhood": "Centro Histórico Cultural",
        },
        {
            "name": "Managua",
            "code": 11002,
            "neighborhood": "Rubén Darío - Candelaria",
        },
        {
            "name": "Managua",
            "code": 11002,
            "neighborhood": "Candelaria",
        },
        {
            "name": "Managua",
            "code": 11003,
            "neighborhood": "Los Pescadores",
        },
        {
            "name": "Managua",
            "code": 11003,
            "neighborhood": "Carlos Reina",
        },
        {
            "name": "Managua",
            "code": 11004,
            "neighborhood": "Quinta Nina",
        },
        {
            "name": "Managua",
            "code": 11004,
            "neighborhood": "Benedicto Valverde",
        },
        {
            "name": "Managua",
            "code": 11005,
            "neighborhood": "San Luis Norte",
        },
        {
            "name": "Managua",
            "code": 11005,
            "neighborhood": "Hilario Sánchez 1",
        },
        {
            "name": "Managua",
            "code": 11006,
            "neighborhood": "Barricada",
        },
        {
            "name": "Managua",
            "code": 11006,
            "neighborhood": "Hilario Sánchez 2",
        },
        {
            "name": "Managua",
            "code": 11007,
            "neighborhood": "Las Torres",
        },
        {
            "name": "Managua",
            "code": 11008,
            "neighborhood": "Villa Pedro Joaquín Chamorro",
        },
        {
            "name": "Managua",
            "code": 11009,
            "neighborhood": "Riguero Norte",
        },
        {
            "name": "Managua",
            "code": 11011,
            "neighborhood": "Domitila Lugo",
        },
        {
            "name": "Managua",
            "code": 11012,
            "neighborhood": "Jardines De Santa Clara",
        },
        {
            "name": "Managua",
            "code": 11013,
            "neighborhood": "Shelim Shible",
        },
        {
            "name": "Managua",
            "code": 11014,
            "neighborhood": "Santa Lucia",
        },
        {
            "name": "Managua",
            "code": 11015,
            "neighborhood": "Sector Oeste Portezuelo",
        },
        {
            "name": "Managua",
            "code": 11016,
            "neighborhood": "Portezuelo Parque Industrial",
        },
        {
            "name": "Managua",
            "code": 11017,
            "neighborhood": "Sector Este Portezuelo",
        },
        {
            "name": "Managua",
            "code": 11018,
            "neighborhood": "La Primavera",
        },
        {
            "name": "Managua",
            "code": 11019,
            "neighborhood": "Anexo La Primavera",
        },
        {"name": "Managua", "code": 11021, "neighborhood": "Vallarta"},
        {
            "name": "Managua",
            "code": 11022,
            "neighborhood": "Sector Este Vallarta",
        },
        {
            "name": "Managua",
            "code": 11023,
            "neighborhood": "Sector Este La Primavera",
        },
        {
            "name": "Managua",
            "code": 11024,
            "neighborhood": "José Dolores Estrada",
        },
        {
            "name": "Managua",
            "code": 11025,
            "neighborhood": "Sector Corte Suprema De Justicia",
        },
        {
            "name": "Managua",
            "code": 11026,
            "neighborhood": "Jorge Casally",
        },
        {
            "name": "Managua",
            "code": 11027,
            "neighborhood": "Waspán Norte",
        },
        {
            "name": "Managua",
            "code": 11028,
            "neighborhood": "Sector Norte De Waspán Norte",
        },
        {
            "name": "Managua",
            "code": 11029,
            "neighborhood": "Santa Maria De Las Victorias",
        },
        {
            "name": "Managua",
            "code": 11031,
            "neighborhood": "Hugo Chávez",
        },
        {
            "name": "Managua",
            "code": 11032,
            "neighborhood": "Camilo Chamorro",
        },
        {
            "name": "Managua",
            "code": 11033,
            "neighborhood": "Sector Noreste Camilo Chamorro",
        },
        {
            "name": "Managua",
            "code": 11034,
            "neighborhood": "Oscar Lino Paz Cubas",
        },
        {
            "name": "Managua",
            "code": 11035,
            "neighborhood": "Bertha Díaz",
        },
        {
            "name": "Managua",
            "code": 11036,
            "neighborhood": "Sector Oeste Américas 2",
        },
        {"name": "Managua", "code": 11037, "neighborhood": "B15"},
        {
            "name": "Managua",
            "code": 11037,
            "neighborhood": "Carlos Núñez",
        },
        {
            "name": "Managua",
            "code": 11037,
            "neighborhood": "Anexo Américas 2",
        },
        {
            "name": "Managua",
            "code": 11038,
            "neighborhood": "José Benito Escobar",
        },
        {
            "name": "Managua",
            "code": 11038,
            "neighborhood": "Américas 2",
        },
        {
            "name": "Managua",
            "code": 11039,
            "neighborhood": "Las Mercedes",
        },
        {
            "name": "Managua",
            "code": 11041,
            "neighborhood": "Anexo 1 Unidad De Propósito",
        },
        {
            "name": "Managua",
            "code": 11042,
            "neighborhood": "Unidad de Propósito",
        },
        {
            "name": "Managua",
            "code": 11043,
            "neighborhood": "German Pomares Américas 2",
        },
        {
            "name": "Managua",
            "code": 11044,
            "neighborhood": "Anexo 2 Unidad De Propósito",
        },
        {
            "name": "Managua",
            "code": 11045,
            "neighborhood": "Colinas De Verona",
        },
        {
            "name": "Managua",
            "code": 11046,
            "neighborhood": "Las Delicias",
        },
        {
            "name": "Managua",
            "code": 11047,
            "neighborhood": "Sector Este América 2",
        },
        {
            "name": "Managua",
            "code": 11048,
            "neighborhood": "Casa Real Etapa 1",
        },
        {
            "name": "Managua",
            "code": 11049,
            "neighborhood": "Casa Real Etapa 2",
        },
        {
            "name": "Managua",
            "code": 11051,
            "neighborhood": "Casa Real Etapa 3",
        },
        {
            "name": "Managua",
            "code": 11052,
            "neighborhood": "Sector Hotel Camino Real",
        },
        {
            "name": "Managua",
            "code": 11053,
            "neighborhood": "Sector Sur Montecristi",
        },
        {
            "name": "Managua",
            "code": 11054,
            "neighborhood": "Escuela Quemada",
        },
        {
            "name": "Managua",
            "code": 11055,
            "neighborhood": "Montecristi",
        },
        {
            "name": "Managua",
            "code": 11056,
            "neighborhood": "Sector Norte Montecristi",
        },
        {
            "name": "Managua",
            "code": 11057,
            "neighborhood": "Sector Norte Aeropuerto Internacional De Managua",
        },
        {
            "name": "Managua",
            "code": 11058,
            "neighborhood": "15 De Mayo Una",
        },
        {
            "name": "Managua",
            "code": 11059,
            "neighborhood": "Sector Hotel Las Mercedes",
        },
        {
            "name": "Managua",
            "code": 11061,
            "neighborhood": "El Rodeito",
        },
        {"name": "Managua", "code": 11062, "neighborhood": "El Rodeo"},
        {
            "name": "Managua",
            "code": 11063,
            "neighborhood": "Sector Rio Santa Elena",
        },
        {
            "name": "Managua",
            "code": 11064,
            "neighborhood": "Santa Elena",
        },
        {
            "name": "Managua",
            "code": 11065,
            "neighborhood": "Monte Fresco",
        },
        {
            "name": "Managua",
            "code": 11066,
            "neighborhood": "Sector Rio Borbollón",
        },
        {
            "name": "Managua",
            "code": 11067,
            "neighborhood": "Sector Rio Lodoso",
        },
        {
            "name": "Managua",
            "code": 11068,
            "neighborhood": "Sector Este Zona Franca Industrial",
        },
        {
            "name": "Managua",
            "code": 11069,
            "neighborhood": "Alexis Arguello",
        },
        {
            "name": "Managua",
            "code": 11071,
            "neighborhood": "Sector Zona Franca Industrial",
        },
        {
            "name": "Managua",
            "code": 11072,
            "neighborhood": "Sector Aeropuerto Internacional De Managua",
        },
        {
            "name": "Managua",
            "code": 11073,
            "neighborhood": "Sector La Subasta",
        },
        {
            "name": "Managua",
            "code": 11074,
            "neighborhood": "Jorge Salazar",
        },
        {
            "name": "Managua",
            "code": 11075,
            "neighborhood": "Reparto Segovia",
        },
        {
            "name": "Managua",
            "code": 11076,
            "neighborhood": "Sector Mercado Mayoreo",
        },
        {
            "name": "Managua",
            "code": 11076,
            "neighborhood": "Concepción de María",
        },
        {
            "name": "Managua",
            "code": 11077,
            "neighborhood": "Canadá Sureste",
        },
        {
            "name": "Managua",
            "code": 11078,
            "neighborhood": "Palestina",
        },
        {
            "name": "Managua",
            "code": 11079,
            "neighborhood": "Villa Israel",
        },
        {
            "name": "Managua",
            "code": 11081,
            "neighborhood": "Villa Reconciliación",
        },
        {
            "name": "Managua",
            "code": 11082,
            "neighborhood": "Sector La Kativo",
        },
        {
            "name": "Managua",
            "code": 11083,
            "neighborhood": "Sector Este Waspán Sur",
        },
        {
            "name": "Managua",
            "code": 11084,
            "neighborhood": "Waspan Sur",
        },
        {
            "name": "Managua",
            "code": 11085,
            "neighborhood": "Anexo Waspán Sur",
        },
        {
            "name": "Managua",
            "code": 11086,
            "neighborhood": "Villa Miguel Gutiérrez",
        },
        {
            "name": "Managua",
            "code": 11087,
            "neighborhood": "Oswaldo Manzanares",
        },
        {"name": "Managua", "code": 11088, "neighborhood": "Mombacho"},
        {
            "name": "Managua",
            "code": 11089,
            "neighborhood": "Sector Norte Ciudad Industrial Xolotlán",
        },
        {
            "name": "Managua",
            "code": 11091,
            "neighborhood": "Ciudad Xolotlán",
        },
        {
            "name": "Managua",
            "code": 11092,
            "neighborhood": "Carlos Marx",
        },
        {
            "name": "Managua",
            "code": 11093,
            "neighborhood": "Pedro Arauz Palacios",
        },
        {
            "name": "Managua",
            "code": 11094,
            "neighborhood": "Nuevo Horizonte",
        },
        {
            "name": "Managua",
            "code": 11095,
            "neighborhood": "Santa Rosa",
        },
        {
            "name": "Managua",
            "code": 11096,
            "neighborhood": "Costa Rica",
        },
        {
            "name": "Managua",
            "code": 11097,
            "neighborhood": "San Luis Sur",
        },
        {
            "name": "Managua",
            "code": 11098,
            "neighborhood": "Leonel Rugama",
        },
        {
            "name": "Managua",
            "code": 11099,
            "neighborhood": "Los Ángeles",
        },
        {
            "name": "Managua",
            "code": 11101,
            "neighborhood": "Sector Mercado Oriental",
        },
        {
            "name": "Managua",
            "code": 11102,
            "neighborhood": "Santo Domingo",
        },
        {
            "name": "Managua",
            "code": 11103,
            "neighborhood": "Sector Sur Centro Histórico",
        },
        {
            "name": "Managua",
            "code": 11104,
            "neighborhood": "Sector Gobierno",
        },
        {
            "name": "Managua",
            "code": 11105,
            "neighborhood": "Blas Real Espinales",
        },
        {"name": "Managua", "code": 11106, "neighborhood": "Sajonia"},
        {
            "name": "Managua",
            "code": 11107,
            "neighborhood": "Buenos Aires",
        },
        {
            "name": "Managua",
            "code": 11107,
            "neighborhood": "19 De Julio",
        },
        {
            "name": "Managua",
            "code": 11108,
            "neighborhood": "Ciudad Jardín",
        },
        {
            "name": "Managua",
            "code": 11109,
            "neighborhood": "Romin Manrique",
        },
        {"name": "Managua", "code": 11111, "neighborhood": "Tenderí"},
        {
            "name": "Managua",
            "code": 11112,
            "neighborhood": "El Paraisito",
        },
        {
            "name": "Managua",
            "code": 11113,
            "neighborhood": "Larreynaga",
        },
        {
            "name": "Managua",
            "code": 11114,
            "neighborhood": "Colonia Edgard Lang",
        },
        {
            "name": "Managua",
            "code": 11115,
            "neighborhood": "Hogar Propio",
        },
        {
            "name": "Managua",
            "code": 11116,
            "neighborhood": "Francisco Meza Rojas",
        },
        {
            "name": "Managua",
            "code": 11117,
            "neighborhood": "Largaespada",
        },
        {
            "name": "Managua",
            "code": 11118,
            "neighborhood": "Loma De Tiscapa",
        },
        {
            "name": "Managua",
            "code": 11119,
            "neighborhood": "Colonia Oscar Pérez Cassar",
        },
        {
            "name": "Managua",
            "code": 11121,
            "neighborhood": "Sector Laguna De Tiscapa",
        },
        {
            "name": "Managua",
            "code": 11122,
            "neighborhood": "Sector Sur Laguna Tiscapa",
        },
        {
            "name": "Managua",
            "code": 11123,
            "neighborhood": "La Florida",
        },
        {
            "name": "Managua",
            "code": 11124,
            "neighborhood": "Villa Tiscapa",
        },
        {
            "name": "Managua",
            "code": 11125,
            "neighborhood": "Sector La Piñata",
        },
        {
            "name": "Managua",
            "code": 11126,
            "neighborhood": "Sector Oeste Avenida Universitaria",
        },
        {
            "name": "Managua",
            "code": 11127,
            "neighborhood": "Sector Noroeste Rotonda Rubén Darío",
        },
        {
            "name": "Managua",
            "code": 11128,
            "neighborhood": "Reparto Walter Ferretí",
        },
        {
            "name": "Managua",
            "code": 11129,
            "neighborhood": "Sector Catedral Metropolitana",
        },
        {
            "name": "Managua",
            "code": 11131,
            "neighborhood": "Reparto Serrano",
        },
        {
            "name": "Managua",
            "code": 11132,
            "neighborhood": "Jorge Dimitrov",
        },
        {
            "name": "Managua",
            "code": 11133,
            "neighborhood": "Enrique Schmitd Rotonda de Cristo",
        },
        {
            "name": "Managua",
            "code": 11134,
            "neighborhood": "Oscar Turcios Rotonda de Cristo",
        },
        {
            "name": "Managua",
            "code": 11135,
            "neighborhood": "Colonia Managua",
        },
        {
            "name": "Managua",
            "code": 11136,
            "neighborhood": "Campo Bruce",
        },
        {
            "name": "Managua",
            "code": 11137,
            "neighborhood": "San José Oriental",
        },
        {
            "name": "Managua",
            "code": 11138,
            "neighborhood": "San Cristóbal",
        },
        {
            "name": "Managua",
            "code": 11139,
            "neighborhood": "María Auxiliadora",
        },
        {"name": "Managua", "code": 11141, "neighborhood": "El Edén"},
        {
            "name": "Managua",
            "code": 11142,
            "neighborhood": "Cristian Pérez",
        },
        {
            "name": "Managua",
            "code": 11142,
            "neighborhood": "Salvadorita",
        },
        {
            "name": "Managua",
            "code": 11143,
            "neighborhood": "Maestro Gabriel",
        },
        {
            "name": "Managua",
            "code": 11144,
            "neighborhood": "Bello Horizonte Etapa 1",
        },
        {
            "name": "Managua",
            "code": 11145,
            "neighborhood": "Bello Horizonte Etapa 2",
        },
        {
            "name": "Managua",
            "code": 11146,
            "neighborhood": "Bello Horizonte Etapa 3",
        },
        {
            "name": "Managua",
            "code": 11147,
            "neighborhood": "Bello Horizonte Etapa 4",
        },
        {
            "name": "Managua",
            "code": 11148,
            "neighborhood": "Bello Horizonte Etapa 5",
        },
        {
            "name": "Managua",
            "code": 11149,
            "neighborhood": "Bello Horizonte Etapa 6",
        },
        {
            "name": "Managua",
            "code": 11151,
            "neighborhood": "Nueva Libia",
        },
        {
            "name": "Managua",
            "code": 11152,
            "neighborhood": "Villa Progreso",
        },
        {
            "name": "Managua",
            "code": 11153,
            "neighborhood": "Villa Rubén Darío",
        },
        {
            "name": "Managua",
            "code": 11154,
            "neighborhood": "Rafaela Herrera",
        },
        {
            "name": "Managua",
            "code": 11155,
            "neighborhood": "Mártires de Ayapal",
        },
        {
            "name": "Managua",
            "code": 11156,
            "neighborhood": "Villa San Jacinto",
        },
        {
            "name": "Managua",
            "code": 11157,
            "neighborhood": "Laureano Mairena",
        },
        {
            "name": "Managua",
            "code": 11158,
            "neighborhood": "Villa Fraternidad",
        },
        {
            "name": "Managua",
            "code": 11159,
            "neighborhood": "Anexo Villa Fraternidad",
        },
        {
            "name": "Managua",
            "code": 11161,
            "neighborhood": "Villa Japón",
        },
        {
            "name": "Managua",
            "code": 11162,
            "neighborhood": "9 de Junio",
        },
        {
            "name": "Managua",
            "code": 11163,
            "neighborhood": "Anexo Georgino Andrade",
        },
        {
            "name": "Managua",
            "code": 11164,
            "neighborhood": "Georgino Andrade",
        },
        {
            "name": "Managua",
            "code": 11165,
            "neighborhood": "neighborhood Primero de Mayo",
        },
        {
            "name": "Managua",
            "code": 11166,
            "neighborhood": "neighborhood Venezuela",
        },
        {"name": "Managua", "code": 11167, "neighborhood": "Ducualí"},
        {
            "name": "Managua",
            "code": 11168,
            "neighborhood": "Paula Corea",
        },
        {
            "name": "Managua",
            "code": 11169,
            "neighborhood": "El Dorado",
        },
        {
            "name": "Managua",
            "code": 11171,
            "neighborhood": "10 De Junio",
        },
        {
            "name": "Managua",
            "code": 11172,
            "neighborhood": "Reparto Colombia",
        },
        {
            "name": "Managua",
            "code": 11173,
            "neighborhood": "Don Bosco",
        },
        {
            "name": "Managua",
            "code": 11174,
            "neighborhood": "Santa Margarita",
        },
        {
            "name": "Managua",
            "code": 11175,
            "neighborhood": "Santa Julia",
        },
        {
            "name": "Managua",
            "code": 11176,
            "neighborhood": "Farabundo Martí",
        },
        {
            "name": "Managua",
            "code": 11177,
            "neighborhood": "Francisco Aguilar",
        },
        {
            "name": "Managua",
            "code": 11178,
            "neighborhood": "Habana 2 Maria",
        },
        {
            "name": "Managua",
            "code": 11179,
            "neighborhood": "Colonia Nicarao",
        },
        {
            "name": "Managua",
            "code": 11181,
            "neighborhood": "Carlos Aguirre",
        },
        {
            "name": "Managua",
            "code": 11182,
            "neighborhood": "Unión Soviética",
        },
        {"name": "Managua", "code": 11183, "neighborhood": "Rubenia"},
        {
            "name": "Managua",
            "code": 11184,
            "neighborhood": "Villa Austria",
        },
        {
            "name": "Managua",
            "code": 11185,
            "neighborhood": "Américas 1",
        },
        {
            "name": "Managua",
            "code": 11186,
            "neighborhood": "Villa Bulgaria",
        },
        {
            "name": "Managua",
            "code": 11187,
            "neighborhood": "Mercado Ivan Montenegro",
        },
        {
            "name": "Managua",
            "code": 11187,
            "neighborhood": "8 De Marzo",
        },
        {
            "name": "Managua",
            "code": 11188,
            "neighborhood": "Villa Revolución",
        },
        {
            "name": "Managua",
            "code": 11188,
            "neighborhood": "Américas 3",
        },
        {
            "name": "Managua",
            "code": 11189,
            "neighborhood": "10 De Enero",
        },
        {
            "name": "Managua",
            "code": 11191,
            "neighborhood": "Reparto López",
        },
        {"name": "Managua", "code": 11192, "neighborhood": "Jericob"},
        {
            "name": "Managua",
            "code": 11193,
            "neighborhood": "Villa Feliz",
        },
        {
            "name": "Managua",
            "code": 11194,
            "neighborhood": "Sector Sur Villa Reconciliación",
        },
        {
            "name": "Managua",
            "code": 11195,
            "neighborhood": "19 De Febrero",
        },
        {"name": "Managua", "code": 11196, "neighborhood": "Betancur"},
        {
            "name": "Managua",
            "code": 11197,
            "neighborhood": "Sector Norte Laureles Norte",
        },
        {
            "name": "Managua",
            "code": 11198,
            "neighborhood": "Laureles Norte",
        },
        {
            "name": "Managua",
            "code": 11199,
            "neighborhood": "Sector Sur 1 Mercado Mayoreo",
        },
        {
            "name": "Managua",
            "code": 11201,
            "neighborhood": "Reparto Simón Bolívar",
        },
        {
            "name": "Managua",
            "code": 11202,
            "neighborhood": "Sector Sur 2 Mercado Mayoreo",
        },
        {
            "name": "Managua",
            "code": 11203,
            "neighborhood": "Planes Del Doral",
        },
        {
            "name": "Managua",
            "code": 11204,
            "neighborhood": "Praderas Del Doral",
        },
        {
            "name": "Managua",
            "code": 11205,
            "neighborhood": "Gertrudis Áreas",
        },
        {
            "name": "Managua",
            "code": 11206,
            "neighborhood": "31 De Diciembre",
        },
        {
            "name": "Managua",
            "code": 11207,
            "neighborhood": "Sector Norte Laureles Sur",
        },
        {
            "name": "Managua",
            "code": 11208,
            "neighborhood": "Cortijo De La Sabana",
        },
        {
            "name": "Managua",
            "code": 11209,
            "neighborhood": "La Curva Sabana Grande",
        },
        {
            "name": "Managua",
            "code": 11211,
            "neighborhood": "Villa Dignidad",
        },
        {
            "name": "Managua",
            "code": 11212,
            "neighborhood": "La Maravilla",
        },
        {
            "name": "Managua",
            "code": 11212,
            "neighborhood": "Sector Norte Sabana Grande",
        },
        {
            "name": "Managua",
            "code": 11213,
            "neighborhood": "Sector Este Sabana Grande",
        },
        {
            "name": "Managua",
            "code": 11214,
            "neighborhood": "Sector Norte Comarca San Cristóbal",
        },
        {
            "name": "Managua",
            "code": 11215,
            "neighborhood": "Sector Noreste Comarca San Cristóbal",
        },
        {
            "name": "Managua",
            "code": 12001,
            "neighborhood": "San Sebastián",
        },
        {
            "name": "Managua",
            "code": 12002,
            "neighborhood": "Manchester",
        },
        {
            "name": "Managua",
            "code": 12003,
            "neighborhood": "Cristo Del Rosario",
        },
        {
            "name": "Managua",
            "code": 12004,
            "neighborhood": "Julio Buitrago",
        },
        {
            "name": "Managua",
            "code": 12005,
            "neighborhood": "Santa Ana Sur",
        },
        {
            "name": "Managua",
            "code": 12006,
            "neighborhood": "Santa Ana Norte",
        },
        {
            "name": "Managua",
            "code": 12007,
            "neighborhood": "Acahualinca",
        },
        {
            "name": "Managua",
            "code": 12008,
            "neighborhood": "Alemania Democrática",
        },
        {
            "name": "Managua",
            "code": 12009,
            "neighborhood": "neighborhood Cuba",
        },
        {
            "name": "Managua",
            "code": 12011,
            "neighborhood": "Rubén Darío",
        },
        {
            "name": "Managua",
            "code": 12012,
            "neighborhood": "Colonia Morazán",
        },
        {
            "name": "Managua",
            "code": 12013,
            "neighborhood": "Rafael Ángel Ríos",
        },
        {
            "name": "Managua",
            "code": 12014,
            "neighborhood": "Sector Norte Linda Vista",
        },
        {
            "name": "Managua",
            "code": 12015,
            "neighborhood": "Sector Occidental Lago De Managua",
        },
        {
            "name": "Managua",
            "code": 12016,
            "neighborhood": "La Chureca",
        },
        {
            "name": "Managua",
            "code": 12017,
            "neighborhood": "Virgen De Guadalupe",
        },
        {
            "name": "Managua",
            "code": 12018,
            "neighborhood": "Sector Norte Las Brisas",
        },
        {
            "name": "Managua",
            "code": 12019,
            "neighborhood": "Linda Vista Norte",
        },
        {
            "name": "Managua",
            "code": 12021,
            "neighborhood": "Las Brisas",
        },
        {
            "name": "Managua",
            "code": 12022,
            "neighborhood": "Carlos Núñez Los Martínez",
        },
        {
            "name": "Managua",
            "code": 12023,
            "neighborhood": "Valle Dorado",
        },
        {
            "name": "Managua",
            "code": 12024,
            "neighborhood": "Sector Cerro Los Martínez",
        },
        {
            "name": "Managua",
            "code": 12025,
            "neighborhood": "Sector Cuesta Del Plomo",
        },
        {
            "name": "Managua",
            "code": 12026,
            "neighborhood": "Sector Industrial La Refinería",
        },
        {"name": "Managua", "code": 12027, "neighborhood": "Ulsa"},
        {
            "name": "Managua",
            "code": 12028,
            "neighborhood": "Sector Paseo Las Brisa",
        },
        {
            "name": "Managua",
            "code": 12029,
            "neighborhood": "Los Arcos",
        },
        {
            "name": "Managua",
            "code": 12031,
            "neighborhood": "Linda Vista Sur",
        },
        {
            "name": "Managua",
            "code": 12032,
            "neighborhood": "Loma Verde",
        },
        {
            "name": "Managua",
            "code": 12033,
            "neighborhood": "El Seminario",
        },
        {
            "name": "Managua",
            "code": 12034,
            "neighborhood": "El Cortijo",
        },
        {
            "name": "Managua",
            "code": 12035,
            "neighborhood": "Dignidad 4 De Mayo",
        },
        {
            "name": "Managua",
            "code": 12036,
            "neighborhood": "Monseñor Lezcano Oeste",
        },
        {
            "name": "Managua",
            "code": 12037,
            "neighborhood": "Monseñor Lezcano Este",
        },
        {
            "name": "Managua",
            "code": 12038,
            "neighborhood": "Javier Cuadra",
        },
        {
            "name": "Managua",
            "code": 12039,
            "neighborhood": "La Reforma",
        },
        {"name": "Managua", "code": 12041, "neighborhood": "San José"},
        {
            "name": "Managua",
            "code": 12042,
            "neighborhood": "San Antonio",
        },
        {
            "name": "Managua",
            "code": 12043,
            "neighborhood": "San Pedro",
        },
        {"name": "Managua", "code": 12044, "neighborhood": "El Bóer"},
        {
            "name": "Managua",
            "code": 12045,
            "neighborhood": "Che Guevara",
        },
        {
            "name": "Managua",
            "code": 12046,
            "neighborhood": "Martha Quezada",
        },
        {
            "name": "Managua",
            "code": 12047,
            "neighborhood": "William Diaz",
        },
        {
            "name": "Managua",
            "code": 12048,
            "neighborhood": "El Carmen",
        },
        {
            "name": "Managua",
            "code": 12049,
            "neighborhood": "Colonia Mantica",
        },
        {
            "name": "Managua",
            "code": 12049,
            "neighborhood": "Callejón Zelaya",
        },
        {
            "name": "Managua",
            "code": 12051,
            "neighborhood": "Las Palmas",
        },
        {
            "name": "Managua",
            "code": 12052,
            "neighborhood": "Manuel Olivares",
        },
        {
            "name": "Managua",
            "code": 12053,
            "neighborhood": "Reparto España",
        },
        {
            "name": "Managua",
            "code": 12054,
            "neighborhood": "Miraflores 1",
        },
        {
            "name": "Managua",
            "code": 12055,
            "neighborhood": "Miraflores 2",
        },
        {
            "name": "Managua",
            "code": 12056,
            "neighborhood": "Juan Emilio Menocal",
        },
        {
            "name": "Managua",
            "code": 12057,
            "neighborhood": "Sector El Seminario",
        },
        {
            "name": "Managua",
            "code": 12058,
            "neighborhood": "Sector Laguna De Asososca",
        },
        {
            "name": "Managua",
            "code": 12059,
            "neighborhood": "Sector Este Laguna De Asososca",
        },
        {
            "name": "Managua",
            "code": 12061,
            "neighborhood": "Dinamarca",
        },
        {
            "name": "Managua",
            "code": 12062,
            "neighborhood": "Batahola Norte",
        },
        {
            "name": "Managua",
            "code": 12063,
            "neighborhood": "Jardines De Managua",
        },
        {
            "name": "Managua",
            "code": 12064,
            "neighborhood": "Edgard Lang",
        },
        {
            "name": "Managua",
            "code": 12065,
            "neighborhood": "Altagracia Norte",
        },
        {"name": "Managua", "code": 12066, "neighborhood": "Bolonia"},
        {
            "name": "Managua",
            "code": 12067,
            "neighborhood": "San Martín",
        },
        {
            "name": "Managua",
            "code": 12068,
            "neighborhood": "25 Aniversario",
        },
        {
            "name": "Managua",
            "code": 12069,
            "neighborhood": "San Ignacio de Waslala",
        },
        {
            "name": "Managua",
            "code": 12071,
            "neighborhood": "Embusa 1 Y 2",
        },
        {
            "name": "Managua",
            "code": 12072,
            "neighborhood": "Anexo Batahola Sur",
        },
        {
            "name": "Managua",
            "code": 12073,
            "neighborhood": "Batahola Sur",
        },
        {
            "name": "Managua",
            "code": 12074,
            "neighborhood": "Llamas Del Bosque",
        },
        {
            "name": "Managua",
            "code": 12075,
            "neighborhood": "Los Madroños",
        },
        {
            "name": "Managua",
            "code": 12076,
            "neighborhood": "Daniel Chavarría",
        },
        {
            "name": "Managua",
            "code": 12077,
            "neighborhood": "Nora Astorga",
        },
        {
            "name": "Managua",
            "code": 12078,
            "neighborhood": "Santa Ana Nicalit",
        },
        {
            "name": "Managua",
            "code": 12079,
            "neighborhood": "Altagracia Sur",
        },
        {
            "name": "Managua",
            "code": 12081,
            "neighborhood": "Bertha Calderon",
        },
        {
            "name": "Managua",
            "code": 12082,
            "neighborhood": "Recreo Norte",
        },
        {
            "name": "Managua",
            "code": 12083,
            "neighborhood": "Bosques De Bolonia",
        },
        {
            "name": "Managua",
            "code": 12084,
            "neighborhood": "Sector Plaza España",
        },
        {
            "name": "Managua",
            "code": 12085,
            "neighborhood": "Plaza España Costado Sur",
        },
        {
            "name": "Managua",
            "code": 12086,
            "neighborhood": "Sector El Retiro",
        },
        {
            "name": "Managua",
            "code": 12087,
            "neighborhood": "Jonathan González",
        },
        {
            "name": "Managua",
            "code": 12088,
            "neighborhood": "Villa Argentina",
        },
        {
            "name": "Managua",
            "code": 12089,
            "neighborhood": "Golfo Pérsico",
        },
        {
            "name": "Managua",
            "code": 12091,
            "neighborhood": "Sector Enel Central",
        },
        {
            "name": "Managua",
            "code": 12092,
            "neighborhood": "Enrique Bermúdez 380",
        },
        {
            "name": "Managua",
            "code": 12093,
            "neighborhood": "Carlos Núñez 380",
        },
        {
            "name": "Managua",
            "code": 12094,
            "neighborhood": "Sector Oeste Avenida Naciones Unidas",
        },
        {
            "name": "Managua",
            "code": 12095,
            "neighborhood": "Rene Cisneros",
        },
        {
            "name": "Managua",
            "code": 12096,
            "neighborhood": "Recreo Sur",
        },
        {
            "name": "Managua",
            "code": 12097,
            "neighborhood": "Andrés Castro",
        },
        {
            "name": "Managua",
            "code": 12098,
            "neighborhood": "Centro Cívico",
        },
        {
            "name": "Managua",
            "code": 12099,
            "neighborhood": "Sector Mercado Israel Lewites",
        },
        {
            "name": "Managua",
            "code": 12101,
            "neighborhood": "Sector Pali Zumen",
        },
        {
            "name": "Managua",
            "code": 12102,
            "neighborhood": "Sector Centro Comercial Nejapa",
        },
        {
            "name": "Managua",
            "code": 12103,
            "neighborhood": "Enrique Schmidt Nejapa",
        },
        {"name": "Managua", "code": 12104, "neighborhood": "Belmonte"},
        {
            "name": "Managua",
            "code": 12105,
            "neighborhood": "David Tejada",
        },
        {
            "name": "Managua",
            "code": 12106,
            "neighborhood": "Sector Cerro Tabuya",
        },
        {
            "name": "Managua",
            "code": 12107,
            "neighborhood": "Sector Parque Las Piedrecitas",
        },
        {
            "name": "Managua",
            "code": 12108,
            "neighborhood": "Motastepe",
        },
        {
            "name": "Managua",
            "code": 12109,
            "neighborhood": "Mirna Ugarte",
        },
        {
            "name": "Managua",
            "code": 12111,
            "neighborhood": "Las Piedrecitas",
        },
        {
            "name": "Managua",
            "code": 12112,
            "neighborhood": "Héroes Y Mártires De Ayapal",
        },
        {
            "name": "Managua",
            "code": 13001,
            "neighborhood": "Casimiro Sotelo",
        },
        {
            "name": "Managua",
            "code": 13002,
            "neighborhood": "Hialeah 1 Y 2",
        },
        {
            "name": "Managua",
            "code": 13002,
            "neighborhood": "Sector Instituto Salomón De La Selva",
        },
        {
            "name": "Managua",
            "code": 13004,
            "neighborhood": "Sector Holiday Inn",
        },
        {
            "name": "Managua",
            "code": 13005,
            "neighborhood": "Sector Ofiplaza",
        },
        {
            "name": "Managua",
            "code": 13006,
            "neighborhood": "Colonia Del Periodista",
        },
        {
            "name": "Managua",
            "code": 13007,
            "neighborhood": "La Esperanza",
        },
        {"name": "Managua", "code": 13008, "neighborhood": "El Pilar"},
        {
            "name": "Managua",
            "code": 13009,
            "neighborhood": "Sector Hospital Bertha Calderón",
        },
        {
            "name": "Managua",
            "code": 13011,
            "neighborhood": "Héroes Y Mártires Del Bocay",
        },
        {
            "name": "Managua",
            "code": 13011,
            "neighborhood": "Colonia Independencia",
        },
        {
            "name": "Managua",
            "code": 13012,
            "neighborhood": "Tierra Prometida",
        },
        {
            "name": "Managua",
            "code": 13013,
            "neighborhood": "Sector Banco Central",
        },
        {"name": "Managua", "code": 13014, "neighborhood": "Frawley"},
        {"name": "Managua", "code": 13015, "neighborhood": "Reisel"},
        {
            "name": "Managua",
            "code": 13016,
            "neighborhood": "Sector Laguna De Nejapa",
        },
        {
            "name": "Managua",
            "code": 13017,
            "neighborhood": "Sector Este Laguna De Nejapa",
        },
        {
            "name": "Managua",
            "code": 13018,
            "neighborhood": "Sector Noroeste Pista Suburbana",
        },
        {
            "name": "Managua",
            "code": 13019,
            "neighborhood": "Lomas De San Judas",
        },
        {
            "name": "Managua",
            "code": 13021,
            "neighborhood": "Herlinda López",
        },
        {
            "name": "Managua",
            "code": 13022,
            "neighborhood": "Luis Alfonso Velásquez 1",
        },
        {
            "name": "Managua",
            "code": 13023,
            "neighborhood": "Luis Alfonso Velásquez 2",
        },
        {
            "name": "Managua",
            "code": 13024,
            "neighborhood": "San Judas",
        },
        {
            "name": "Managua",
            "code": 13025,
            "neighborhood": "Los Martínez San Judas",
        },
        {
            "name": "Managua",
            "code": 13026,
            "neighborhood": "Sector Este San Judas",
        },
        {
            "name": "Managua",
            "code": 13027,
            "neighborhood": "San Pedro San Judas",
        },
        {
            "name": "Managua",
            "code": 13028,
            "neighborhood": "Vista Hermosa",
        },
        {
            "name": "Managua",
            "code": 13029,
            "neighborhood": "Martin Luter King",
        },
        {
            "name": "Managua",
            "code": 13031,
            "neighborhood": "Paseo Del Valle",
        },
        {
            "name": "Managua",
            "code": 13032,
            "neighborhood": "San Francisco De Asís",
        },
        {
            "name": "Managua",
            "code": 13033,
            "neighborhood": "Memorial Sandino",
        },
        {
            "name": "Managua",
            "code": 13034,
            "neighborhood": "Bosques De Nejapa",
        },
        {
            "name": "Managua",
            "code": 13035,
            "neighborhood": "Sector Suroeste Colonia El Periodista",
        },
        {
            "name": "Managua",
            "code": 13036,
            "neighborhood": "Altos De Nejapa",
        },
        {
            "name": "Managua",
            "code": 13037,
            "neighborhood": "Hialeah 3",
        },
        {
            "name": "Managua",
            "code": 13038,
            "neighborhood": "Hialeah 4",
        },
        {
            "name": "Managua",
            "code": 13039,
            "neighborhood": "Sector Oeste Lomas De San Ángel",
        },
        {
            "name": "Managua",
            "code": 13041,
            "neighborhood": "Villa San Ángel",
        },
        {
            "name": "Managua",
            "code": 13042,
            "neighborhood": "Lomas De San Ángel",
        },
        {
            "name": "Managua",
            "code": 13043,
            "neighborhood": "Lomas De Monserrat",
        },
        {"name": "Managua", "code": 13044, "neighborhood": "Catalina"},
        {
            "name": "Managua",
            "code": 13045,
            "neighborhood": "Acrópolis",
        },
        {
            "name": "Managua",
            "code": 13046,
            "neighborhood": "Sector Noroeste Rotonda Universitaria",
        },
        {
            "name": "Managua",
            "code": 13047,
            "neighborhood": "Lomas Del Consuelo",
        },
        {
            "name": "Managua",
            "code": 13048,
            "neighborhood": "Sector Colegio Americano",
        },
        {
            "name": "Managua",
            "code": 13049,
            "neighborhood": "Sector Suroeste Rotonda Universitaria",
        },
        {
            "name": "Managua",
            "code": 13051,
            "neighborhood": "Colonia Miguel Bonilla",
        },
        {
            "name": "Managua",
            "code": 13052,
            "neighborhood": "Sector Mokorón",
        },
        {
            "name": "Managua",
            "code": 13053,
            "neighborhood": "Sector Norte Comarca Los Ladinos",
        },
        {
            "name": "Managua",
            "code": 13054,
            "neighborhood": "Sector Sur Memorial Sandino",
        },
        {
            "name": "Managua",
            "code": 13055,
            "neighborhood": "Marvin Marín",
        },
        {
            "name": "Managua",
            "code": 13056,
            "neighborhood": "Villa Roma",
        },
        {
            "name": "Managua",
            "code": 13057,
            "neighborhood": "Omar Torrijos - Loma Linda",
        },
        {
            "name": "Managua",
            "code": 13058,
            "neighborhood": "Lomas De Buenos Aires",
        },
        {
            "name": "Managua",
            "code": 13059,
            "neighborhood": "Sector Suroeste Pista Suburbana",
        },
        {
            "name": "Managua",
            "code": 13061,
            "neighborhood": "San Patricio",
        },
        {"name": "Managua", "code": 13062, "neighborhood": "Kilocho"},
        {
            "name": "Managua",
            "code": 13063,
            "neighborhood": "Germán Pomares -Ticomo",
        },
        {
            "name": "Managua",
            "code": 13064,
            "neighborhood": "Arges Sequeira",
        },
        {
            "name": "Managua",
            "code": 13065,
            "neighborhood": "Sector Noreste Valle De Ticomo",
        },
        {
            "name": "Managua",
            "code": 13066,
            "neighborhood": "Villa Nueva",
        },
        {
            "name": "Managua",
            "code": 13067,
            "neighborhood": "Lomas Del Sur",
        },
        {
            "name": "Managua",
            "code": 13068,
            "neighborhood": "Buena Vista",
        },
        {
            "name": "Managua",
            "code": 13069,
            "neighborhood": "Bertilda Olegaria",
        },
        {
            "name": "Managua",
            "code": 13071,
            "neighborhood": "La Zacatera",
        },
        {
            "name": "Managua",
            "code": 13072,
            "neighborhood": "Los Laureles- Camilo Ortega",
        },
        {
            "name": "Managua",
            "code": 13073,
            "neighborhood": "Sector Sureste Valle Ticomo",
        },
        {
            "name": "Managua",
            "code": 13074,
            "neighborhood": "William Galeano",
        },
        {
            "name": "Managua",
            "code": 13075,
            "neighborhood": "Camilo Ortega",
        },
        {
            "name": "Managua",
            "code": 13075,
            "neighborhood": "Torres Molina",
        },
        {
            "name": "Managua",
            "code": 13076,
            "neighborhood": "Anexo Camilo Ortega",
        },
        {
            "name": "Managua",
            "code": 13077,
            "neighborhood": "Sector Sur Loma Linda",
        },
        {
            "name": "Managua",
            "code": 13078,
            "neighborhood": "Loma Linda",
        },
        {
            "name": "Managua",
            "code": 13078,
            "neighborhood": "Sierra Maestra",
        },
        {
            "name": "Managua",
            "code": 13079,
            "neighborhood": "Anexo Villa Roma",
        },
        {
            "name": "Managua",
            "code": 13081,
            "neighborhood": "Sector Noreste Comarca Pochocuape",
        },
        {
            "name": "Managua",
            "code": 13082,
            "neighborhood": "Sector Noroeste Comarca San Isidro Libertador",
        },
        {
            "name": "Managua",
            "code": 13083,
            "neighborhood": "Sector Norte Comarca San Isidro Libertador",
        },
        {
            "name": "Managua",
            "code": 13084,
            "neighborhood": "Sector Sur Comarca Los Ladinos",
        },
        {
            "name": "Managua",
            "code": 13085,
            "neighborhood": "El Progreso",
        },
        {
            "name": "Managua",
            "code": 13086,
            "neighborhood": "Sector Norte Comarca Las Viudas",
        },
        {
            "name": "Managua",
            "code": 13087,
            "neighborhood": "Sector Sur Comarca Las Viudas",
        },
        {
            "name": "Managua",
            "code": 13088,
            "neighborhood": "Sector Sur Comarca San Isidro Libertador",
        },
        {
            "name": "Managua",
            "code": 13089,
            "neighborhood": "Sector Sur Comarca Pochocuape",
        },
        {
            "name": "Managua",
            "code": 13091,
            "neighborhood": "Sector Sur Comarca Ticomo",
        },
        {
            "name": "Managua",
            "code": 13092,
            "neighborhood": "Sector Sur Valle Ticomo",
        },
        {
            "name": "Managua",
            "code": 13093,
            "neighborhood": "Sector Valle De Ticomo",
        },
        {
            "name": "Managua",
            "code": 13094,
            "neighborhood": "Sector Sur Laguna Nejapa",
        },
        {"name": "Managua", "code": 13095, "neighborhood": "Nejapa"},
        {
            "name": "Managua",
            "code": 13096,
            "neighborhood": "Sector Norte Comarca Nejapa",
        },
        {
            "name": "Managua",
            "code": 13097,
            "neighborhood": "German Pomares- Nejapa",
        },
        {
            "name": "Managua",
            "code": 13098,
            "neighborhood": "Delagneau",
        },
        {
            "name": "Managua",
            "code": 13099,
            "neighborhood": "Villa Galicia",
        },
        {
            "name": "Managua",
            "code": 13101,
            "neighborhood": "Sector Noroeste Altos De Ticomo",
        },
        {
            "name": "Managua",
            "code": 13102,
            "neighborhood": "Sector Sur Comarca Nejapa",
        },
        {
            "name": "Managua",
            "code": 13103,
            "neighborhood": "Bosques De Miraflores",
        },
        {
            "name": "Managua",
            "code": 13104,
            "neighborhood": "Sector Oeste Comarca Nejapa",
        },
        {
            "name": "Managua",
            "code": 13105,
            "neighborhood": "Sector Norte Cedro Galán",
        },
        {
            "name": "Managua",
            "code": 13106,
            "neighborhood": "Sector Central Comarca Cedro Galán",
        },
        {
            "name": "Managua",
            "code": 13107,
            "neighborhood": "Sector Norte Comarca Chiquilistagua",
        },
        {
            "name": "Managua",
            "code": 13108,
            "neighborhood": "Lomas De Maromo",
        },
        {
            "name": "Managua",
            "code": 13109,
            "neighborhood": "Sector Central Comarca Chiquilistagua",
        },
        {
            "name": "Managua",
            "code": 13111,
            "neighborhood": "Vista Esmeralda",
        },
        {
            "name": "Managua",
            "code": 13112,
            "neighborhood": "Sector Oeste Comarca Chiquilistagua",
        },
        {
            "name": "Managua",
            "code": 13113,
            "neighborhood": "Casa Blanca",
        },
        {
            "name": "Managua",
            "code": 13114,
            "neighborhood": "Monte Verde",
        },
        {
            "name": "Managua",
            "code": 13115,
            "neighborhood": "Planetarium",
        },
        {
            "name": "Managua",
            "code": 13116,
            "neighborhood": "Sector Este Comarca Chiquilistagua",
        },
        {
            "name": "Managua",
            "code": 13117,
            "neighborhood": "Sector Suroeste Comarca Cedro Galán",
        },
        {
            "name": "Managua",
            "code": 13118,
            "neighborhood": "Sector Sur Comarca Cedro Galán",
        },
        {
            "name": "Managua",
            "code": 13119,
            "neighborhood": "Sector Noroeste Comarca San Jose De La Cañada",
        },
        {
            "name": "Managua",
            "code": 13121,
            "neighborhood": "Altos De Ticomo",
        },
        {
            "name": "Managua",
            "code": 13122,
            "neighborhood": "Lomas De Ticomo",
        },
        {
            "name": "Managua",
            "code": 13123,
            "neighborhood": "Santa Anita",
        },
        {
            "name": "Managua",
            "code": 13124,
            "neighborhood": "Santa Anita 2",
        },
        {
            "name": "Managua",
            "code": 13125,
            "neighborhood": "Marcell Pallais",
        },
        {
            "name": "Managua",
            "code": 13125,
            "neighborhood": "Santa Isabel",
        },
        {
            "name": "Managua",
            "code": 13126,
            "neighborhood": "Sector Suroeste Santa Anita",
        },
        {
            "name": "Managua",
            "code": 13127,
            "neighborhood": "San Sebastián Sur",
        },
        {
            "name": "Managua",
            "code": 13128,
            "neighborhood": "Sector Este Comarca San Jose De La Cañada",
        },
        {
            "name": "Managua",
            "code": 13129,
            "neighborhood": "Sector Sureste Santa Isabel",
        },
        {
            "name": "Managua",
            "code": 13131,
            "neighborhood": "El Sosiego",
        },
        {
            "name": "Managua",
            "code": 13132,
            "neighborhood": "Samarkanda",
        },
        {
            "name": "Managua",
            "code": 13133,
            "neighborhood": "Villa Jacinto",
        },
        {
            "name": "Managua",
            "code": 13134,
            "neighborhood": "Sector Oeste Monte Tabor",
        },
        {
            "name": "Managua",
            "code": 13135,
            "neighborhood": "Serranías",
        },
        {
            "name": "Managua",
            "code": 13135,
            "neighborhood": "Las Carolinas",
        },
        {
            "name": "Managua",
            "code": 13136,
            "neighborhood": "Los Cocos",
        },
        {
            "name": "Managua",
            "code": 13137,
            "neighborhood": "Urbanización Ticomo Sur",
        },
        {
            "name": "Managua",
            "code": 13138,
            "neighborhood": "Sector Este Comarca Monte Tabor",
        },
        {
            "name": "Managua",
            "code": 13139,
            "neighborhood": "Las Jinotepes",
        },
        {
            "name": "Managua",
            "code": 13141,
            "neighborhood": "El Pedernal",
        },
        {"name": "Managua", "code": 13142, "neighborhood": "El Rosal"},
        {
            "name": "Managua",
            "code": 13143,
            "neighborhood": "Hilario Sánchez Sur",
        },
        {
            "name": "Managua",
            "code": 13144,
            "neighborhood": "Sector Sureste Comarca San Jose La Cañada",
        },
        {
            "name": "Managua",
            "code": 13145,
            "neighborhood": "La Veranera",
        },
        {
            "name": "Managua",
            "code": 13146,
            "neighborhood": "Sector Suroeste Comarca San Jose La Cañada",
        },
        {
            "name": "Managua",
            "code": 14001,
            "neighborhood": "Edgard Munguía",
        },
        {
            "name": "Managua",
            "code": 14002,
            "neighborhood": "Reparto San Juan",
        },
        {
            "name": "Managua",
            "code": 14003,
            "neighborhood": "Reparto Lomas De Guadalupe",
        },
        {
            "name": "Managua",
            "code": 14004,
            "neighborhood": "Reparto Tiscapa",
        },
        {
            "name": "Managua",
            "code": 14005,
            "neighborhood": "Sector Metrocentro",
        },
        {
            "name": "Managua",
            "code": 14006,
            "neighborhood": "Colonial Los Robles 3",
        },
        {
            "name": "Managua",
            "code": 14007,
            "neighborhood": "Colonial Los Robles 5",
        },
        {
            "name": "Managua",
            "code": 14008,
            "neighborhood": "Colonial Los Robles 7",
        },
        {
            "name": "Managua",
            "code": 14009,
            "neighborhood": "Colonial Los Robles 8",
        },
        {
            "name": "Managua",
            "code": 14011,
            "neighborhood": "Pedro Joaquín Chamorro",
        },
        {"name": "Managua", "code": 14012, "neighborhood": "La Luz"},
        {
            "name": "Managua",
            "code": 14012,
            "neighborhood": "14 De Junio",
        },
        {
            "name": "Managua",
            "code": 14013,
            "neighborhood": "Habana 1 - Rotonda De Cristo",
        },
        {"name": "Managua", "code": 14014, "neighborhood": "Riguero"},
        {
            "name": "Managua",
            "code": 14015,
            "neighborhood": "Aldo Chavarría",
        },
        {
            "name": "Managua",
            "code": 14016,
            "neighborhood": "Máximo Jerez",
        },
        {
            "name": "Managua",
            "code": 14017,
            "neighborhood": "neighborhood México",
        },
        {
            "name": "Managua",
            "code": 14018,
            "neighborhood": "Revolución",
        },
        {"name": "Managua", "code": 14019, "neighborhood": "Liberia"},
        {
            "name": "Managua",
            "code": 14021,
            "neighborhood": "Carlos Fonseca",
        },
        {
            "name": "Managua",
            "code": 14022,
            "neighborhood": "Sector Mercado Roberto Huembes",
        },
        {
            "name": "Managua",
            "code": 14023,
            "neighborhood": "Isaías Gómez",
        },
        {
            "name": "Managua",
            "code": 14024,
            "neighborhood": "Sector Hospital Manolo Morales",
        },
        {
            "name": "Managua",
            "code": 14025,
            "neighborhood": "Santos López",
        },
        {
            "name": "Managua",
            "code": 14026,
            "neighborhood": "Bosques De Altamira",
        },
        {
            "name": "Managua",
            "code": 14027,
            "neighborhood": "Altamira del Este",
        },
        {
            "name": "Managua",
            "code": 14028,
            "neighborhood": "Colonial Los Robles 6",
        },
        {
            "name": "Managua",
            "code": 14029,
            "neighborhood": "Colonial Los Robles 2",
        },
        {
            "name": "Managua",
            "code": 14031,
            "neighborhood": "Planes De Altamira 2",
        },
        {
            "name": "Managua",
            "code": 14032,
            "neighborhood": "Colonial Los Robles 4",
        },
        {
            "name": "Managua",
            "code": 14033,
            "neighborhood": "Colonial Los Robles 1",
        },
        {
            "name": "Managua",
            "code": 14034,
            "neighborhood": "Planes De Altamira 1",
        },
        {
            "name": "Managua",
            "code": 14035,
            "neighborhood": "Reparto Los Robles",
        },
        {
            "name": "Managua",
            "code": 14036,
            "neighborhood": "Anexo Reparto San Juan",
        },
        {
            "name": "Managua",
            "code": 14037,
            "neighborhood": "Lomas De San Juan",
        },
        {
            "name": "Managua",
            "code": 14038,
            "neighborhood": "Villa Santa Fe",
        },
        {
            "name": "Managua",
            "code": 14039,
            "neighborhood": "Sector Sur San Juan",
        },
        {
            "name": "Managua",
            "code": 14041,
            "neighborhood": "Sector Sureste San Juan",
        },
        {
            "name": "Managua",
            "code": 14042,
            "neighborhood": "Planes De Altamira 3",
        },
        {
            "name": "Managua",
            "code": 14043,
            "neighborhood": "Sector Este Planes De Altamira 3",
        },
        {
            "name": "Managua",
            "code": 14044,
            "neighborhood": "Las Flores",
        },
        {"name": "Managua", "code": 14045, "neighborhood": "Bell Air"},
        {
            "name": "Managua",
            "code": 14046,
            "neighborhood": "Sector Noroeste Paso Desnivel Centroamérica",
        },
        {
            "name": "Managua",
            "code": 14047,
            "neighborhood": "La Morita",
        },
        {
            "name": "Managua",
            "code": 14048,
            "neighborhood": "Colonia Centroamérica",
        },
        {
            "name": "Managua",
            "code": 14049,
            "neighborhood": "Sector Centro Comercial Managua",
        },
        {"name": "Managua", "code": 14051, "neighborhood": "Pantasma"},
        {"name": "Managua", "code": 14052, "neighborhood": "Grenada"},
        {
            "name": "Managua",
            "code": 14053,
            "neighborhood": "Ariel Darce",
        },
        {
            "name": "Managua",
            "code": 14053,
            "neighborhood": "La Fuente",
        },
        {
            "name": "Managua",
            "code": 14054,
            "neighborhood": "Reparto Cuadra",
        },
        {
            "name": "Managua",
            "code": 14055,
            "neighborhood": "Nicarao Sector Sur",
        },
        {
            "name": "Managua",
            "code": 14056,
            "neighborhood": "Edmundo Matamoros",
        },
        {
            "name": "Managua",
            "code": 14056,
            "neighborhood": "Santa Bárbara",
        },
        {
            "name": "Managua",
            "code": 14057,
            "neighborhood": "14 De Septiembre",
        },
        {
            "name": "Managua",
            "code": 14058,
            "neighborhood": "Omar Torrijos",
        },
        {
            "name": "Managua",
            "code": 14058,
            "neighborhood": "Santa Emilia",
        },
        {
            "name": "Managua",
            "code": 14059,
            "neighborhood": "Jardines De Veracruz",
        },
        {
            "name": "Managua",
            "code": 14061,
            "neighborhood": "Anexo Jardines De Veracruz",
        },
        {
            "name": "Managua",
            "code": 14062,
            "neighborhood": "Sector Conchita Palacios",
        },
        {
            "name": "Managua",
            "code": 14063,
            "neighborhood": "Leningrado",
        },
        {
            "name": "Managua",
            "code": 14064,
            "neighborhood": "Colonia Primero De Mayo",
        },
        {
            "name": "Managua",
            "code": 14065,
            "neighborhood": "Anexo Colonia Primero De Mayo",
        },
        {
            "name": "Managua",
            "code": 14066,
            "neighborhood": "Villa Valencia",
        },
        {
            "name": "Managua",
            "code": 14067,
            "neighborhood": "Villa Flor Norte",
        },
        {
            "name": "Managua",
            "code": 14068,
            "neighborhood": "Las Alemanias",
        },
        {
            "name": "Managua",
            "code": 14069,
            "neighborhood": "Bosque Norte Y Sur",
        },
        {
            "name": "Managua",
            "code": 14071,
            "neighborhood": "Américas 4",
        },
        {
            "name": "Managua",
            "code": 14071,
            "neighborhood": "Villa Venezuela",
        },
        {
            "name": "Managua",
            "code": 14072,
            "neighborhood": "Villa La Sabana",
        },
        {
            "name": "Managua",
            "code": 14073,
            "neighborhood": "Sector Este Villa Venezuela",
        },
        {
            "name": "Managua",
            "code": 14074,
            "neighborhood": "Arlen Siu",
        },
        {
            "name": "Managua",
            "code": 14075,
            "neighborhood": "Mirador La Sabana",
        },
        {
            "name": "Managua",
            "code": 14076,
            "neighborhood": "Manuel Fernández",
        },
        {
            "name": "Managua",
            "code": 14076,
            "neighborhood": "Laureles Sur",
        },
        {
            "name": "Managua",
            "code": 14077,
            "neighborhood": "Arnoldo Alemán",
        },
        {
            "name": "Managua",
            "code": 14078,
            "neighborhood": "Maria Dolores Alemán",
        },
        {"name": "Managua", "code": 14079, "neighborhood": "Vittoria"},
        {
            "name": "Managua",
            "code": 14081,
            "neighborhood": "Sector Este Laureles Sur",
        },
        {
            "name": "Managua",
            "code": 14082,
            "neighborhood": "Altos De La Sabana",
        },
        {
            "name": "Managua",
            "code": 14083,
            "neighborhood": "Los Cocos Sabana Grande",
        },
        {
            "name": "Managua",
            "code": 14084,
            "neighborhood": "4 De Noviembre",
        },
        {
            "name": "Managua",
            "code": 14085,
            "neighborhood": "Sabana Grande",
        },
        {
            "name": "Managua",
            "code": 14086,
            "neighborhood": "Ríos De Agua Viva",
        },
        {
            "name": "Managua",
            "code": 14087,
            "neighborhood": "Sector Sur Sabana Grande",
        },
        {
            "name": "Managua",
            "code": 14088,
            "neighborhood": "Sector Sur Comarca San Cristóbal",
        },
        {
            "name": "Managua",
            "code": 14089,
            "neighborhood": "Sector Este 2 Comarca Sabana Grande Sur",
        },
        {
            "name": "Managua",
            "code": 14091,
            "neighborhood": "Villa Sol",
        },
        {"name": "Managua", "code": 14092, "neighborhood": "Sabanas"},
        {
            "name": "Managua",
            "code": 14093,
            "neighborhood": "Sector Este 1 Comarca Sabana Grande Sur",
        },
        {
            "name": "Managua",
            "code": 14094,
            "neighborhood": "Sector Oeste Comarca Sabana Grande Sur",
        },
        {
            "name": "Managua",
            "code": 14095,
            "neighborhood": "Israel Galeano",
        },
        {
            "name": "Managua",
            "code": 14096,
            "neighborhood": "Nueva Sabana",
        },
        {
            "name": "Managua",
            "code": 14097,
            "neighborhood": "Comandante Aureleano",
        },
        {
            "name": "Managua",
            "code": 14098,
            "neighborhood": "Camino Del Río",
        },
        {
            "name": "Managua",
            "code": 14099,
            "neighborhood": "Los Ingenieros",
        },
        {
            "name": "Managua",
            "code": 14099,
            "neighborhood": "Sector Sur Lomas De Guadalupe",
        },
        {
            "name": "Managua",
            "code": 14099,
            "neighborhood": "Los Corteses",
        },
        {
            "name": "Managua",
            "code": 14101,
            "neighborhood": "Lomas De Guadalupe",
        },
        {
            "name": "Managua",
            "code": 14102,
            "neighborhood": "Villa Libertad",
        },
        {
            "name": "Managua",
            "code": 14103,
            "neighborhood": "Anexo Villa Libertad",
        },
        {
            "name": "Managua",
            "code": 14104,
            "neighborhood": "Sol De Libertad",
        },
        {
            "name": "Managua",
            "code": 14105,
            "neighborhood": "Nueva Nicaragua",
        },
        {
            "name": "Managua",
            "code": 14106,
            "neighborhood": "Divino Niño",
        },
        {
            "name": "Managua",
            "code": 14107,
            "neighborhood": "Ciudad San Sebastián",
        },
        {
            "name": "Managua",
            "code": 14108,
            "neighborhood": "Sector Sur Anexo Villa Libertad",
        },
        {
            "name": "Managua",
            "code": 14109,
            "neighborhood": "Milagro De Dios",
        },
        {
            "name": "Managua",
            "code": 14111,
            "neighborhood": "Anexo Villa Venezuela",
        },
        {
            "name": "Managua",
            "code": 14112,
            "neighborhood": "Vistas Xolotlán",
        },
        {
            "name": "Managua",
            "code": 14113,
            "neighborhood": "Carlos Núñez Américas 4",
        },
        {
            "name": "Managua",
            "code": 14114,
            "neighborhood": "Villa Canadá",
        },
        {
            "name": "Managua",
            "code": 14115,
            "neighborhood": "Manolo Morales",
        },
        {
            "name": "Managua",
            "code": 14116,
            "neighborhood": "25 De Febrero",
        },
        {
            "name": "Managua",
            "code": 14117,
            "neighborhood": "Villa Flor Sur",
        },
        {
            "name": "Managua",
            "code": 14118,
            "neighborhood": "Enrique Schmidt Villa Flor",
        },
        {
            "name": "Managua",
            "code": 14119,
            "neighborhood": "11 De Mayo",
        },
        {
            "name": "Managua",
            "code": 14121,
            "neighborhood": "13 De Mayo",
        },
        {
            "name": "Managua",
            "code": 14122,
            "neighborhood": "18 De Agosto",
        },
        {
            "name": "Managua",
            "code": 14123,
            "neighborhood": "Ciudadela Nicaragua",
        },
        {
            "name": "Managua",
            "code": 14124,
            "neighborhood": "28 De Mayo",
        },
        {
            "name": "Managua",
            "code": 14125,
            "neighborhood": "Eddy Mayorga",
        },
        {
            "name": "Managua",
            "code": 14126,
            "neighborhood": "Eduardo Contreras",
        },
        {
            "name": "Managua",
            "code": 14127,
            "neighborhood": "30 De Mayo",
        },
        {
            "name": "Managua",
            "code": 14127,
            "neighborhood": "Sector Milagro De Dios",
        },
        {
            "name": "Managua",
            "code": 14128,
            "neighborhood": "Alfredo Nobel",
        },
        {
            "name": "Managua",
            "code": 14128,
            "neighborhood": "Che Guevara",
        },
        {
            "name": "Managua",
            "code": 14129,
            "neighborhood": "Salomón Moreno",
        },
        {
            "name": "Managua",
            "code": 14131,
            "neighborhood": "Enrique Lorente",
        },
        {
            "name": "Managua",
            "code": 14131,
            "neighborhood": "Reparto Shick 3",
        },
        {
            "name": "Managua",
            "code": 14132,
            "neighborhood": "Bariloche",
        },
        {
            "name": "Managua",
            "code": 14132,
            "neighborhood": "Blanca Segovia",
        },
        {
            "name": "Managua",
            "code": 14133,
            "neighborhood": "Blanca Arauz",
        },
        {
            "name": "Managua",
            "code": 14133,
            "neighborhood": "Amanda Aguilar",
        },
        {
            "name": "Managua",
            "code": 14134,
            "neighborhood": "Sócrates Sandino",
        },
        {
            "name": "Managua",
            "code": 14135,
            "neighborhood": "Reparto Shick 4",
        },
        {
            "name": "Managua",
            "code": 14135,
            "neighborhood": "Enrique Gutiérrez",
        },
        {
            "name": "Managua",
            "code": 14136,
            "neighborhood": "Ángel Valentín neighborhoods",
        },
        {
            "name": "Managua",
            "code": 14136,
            "neighborhood": "Reparto Shick 2",
        },
        {
            "name": "Managua",
            "code": 14137,
            "neighborhood": "Rene Polanco",
        },
        {
            "name": "Managua",
            "code": 14138,
            "neighborhood": "Germán Pomares",
        },
        {
            "name": "Managua",
            "code": 14139,
            "neighborhood": "Proyecto Piloto",
        },
        {
            "name": "Managua",
            "code": 14141,
            "neighborhood": "Pablo Úbeda",
        },
        {"name": "Managua", "code": 14142, "neighborhood": "Macaraly"},
        {
            "name": "Managua",
            "code": 14142,
            "neighborhood": "Reparto Shick 1",
        },
        {
            "name": "Managua",
            "code": 14143,
            "neighborhood": "Francisco Salazar",
        },
        {
            "name": "Managua",
            "code": 14144,
            "neighborhood": "Finlandia Rubén Darío Las Colinas",
        },
        {
            "name": "Managua",
            "code": 14145,
            "neighborhood": "Augusto Cesar Sandino",
        },
        {
            "name": "Managua",
            "code": 14146,
            "neighborhood": "12 De Octubre",
        },
        {
            "name": "Managua",
            "code": 14147,
            "neighborhood": "San Lucas",
        },
        {
            "name": "Managua",
            "code": 14148,
            "neighborhood": "Anexo 18 De Mayo",
        },
        {
            "name": "Managua",
            "code": 14149,
            "neighborhood": "18 De Mayo",
        },
        {
            "name": "Managua",
            "code": 14151,
            "neighborhood": "Walter Ferreti",
        },
        {
            "name": "Managua",
            "code": 14152,
            "neighborhood": "Isabel Urbina",
        },
        {
            "name": "Managua",
            "code": 14152,
            "neighborhood": "Adolfo Reyes",
        },
        {
            "name": "Managua",
            "code": 14153,
            "neighborhood": "Sector Hogar Zacarías Guerra",
        },
        {
            "name": "Managua",
            "code": 14154,
            "neighborhood": "Lomas Del Valle",
        },
        {
            "name": "Managua",
            "code": 14155,
            "neighborhood": "Piquín Guerrero",
        },
        {
            "name": "Managua",
            "code": 14155,
            "neighborhood": "Las Lomitas Centroamérica",
        },
        {
            "name": "Managua",
            "code": 14156,
            "neighborhood": "22 De Enero",
        },
        {
            "name": "Managua",
            "code": 14157,
            "neighborhood": "Sector Camino De Oriente",
        },
        {
            "name": "Managua",
            "code": 14158,
            "neighborhood": "Sector Noroeste Rotonda Jean Paul Genie",
        },
        {
            "name": "Managua",
            "code": 14159,
            "neighborhood": "Planes De Puntaldía",
        },
        {
            "name": "Managua",
            "code": 14161,
            "neighborhood": "Villas Italianas",
        },
        {"name": "Managua", "code": 14162, "neighborhood": "Mirasol"},
        {
            "name": "Managua",
            "code": 14163,
            "neighborhood": "Madroños Villa Fontana",
        },
        {
            "name": "Managua",
            "code": 14164,
            "neighborhood": "Inmaculada Villa Fontana",
        },
        {
            "name": "Managua",
            "code": 14165,
            "neighborhood": "Villa Fontana Este",
        },
        {
            "name": "Managua",
            "code": 14166,
            "neighborhood": "Sector Suroeste Camino De Oriente",
        },
        {
            "name": "Managua",
            "code": 14167,
            "neighborhood": "Sector Radio Nicaragua",
        },
        {
            "name": "Managua",
            "code": 14168,
            "neighborhood": "Sector La Salle",
        },
        {
            "name": "Managua",
            "code": 14169,
            "neighborhood": "Condominio Roma",
        },
        {
            "name": "Managua",
            "code": 14171,
            "neighborhood": "Casa Fontana",
        },
        {
            "name": "Managua",
            "code": 14172,
            "neighborhood": "Sector Unan Managua",
        },
        {
            "name": "Managua",
            "code": 14173,
            "neighborhood": "Villa Fontana Norte",
        },
        {
            "name": "Managua",
            "code": 14174,
            "neighborhood": "Villa Fontana Sur",
        },
        {
            "name": "Managua",
            "code": 14175,
            "neighborhood": "Las Veraneras",
        },
        {
            "name": "Managua",
            "code": 14176,
            "neighborhood": "Sector Comarca Jocote Dulce",
        },
        {
            "name": "Managua",
            "code": 14177,
            "neighborhood": "Sector Colegio Centroamérica",
        },
        {
            "name": "Managua",
            "code": 14178,
            "neighborhood": "Bosques Del Recreo",
        },
        {
            "name": "Managua",
            "code": 14179,
            "neighborhood": "Sector Sur Club Terraza",
        },
        {
            "name": "Managua",
            "code": 14181,
            "neighborhood": "Bosques Del Terraza",
        },
        {
            "name": "Managua",
            "code": 14182,
            "neighborhood": "Las Cumbres",
        },
        {
            "name": "Managua",
            "code": 14183,
            "neighborhood": "Mirador Las Cumbres",
        },
        {
            "name": "Managua",
            "code": 14184,
            "neighborhood": "Altos De Las Cumbres",
        },
        {
            "name": "Managua",
            "code": 14185,
            "neighborhood": "Portal Del Carmen",
        },
        {"name": "Managua", "code": 14186, "neighborhood": "La Rioja"},
        {
            "name": "Managua",
            "code": 14187,
            "neighborhood": "Sector Sur Pista Jean Paul Genie",
        },
        {
            "name": "Managua",
            "code": 14188,
            "neighborhood": "Santa Mónica Cruz Del Paraíso",
        },
        {
            "name": "Managua",
            "code": 14189,
            "neighborhood": "Sector Norte Cruz Del Paraíso",
        },
        {
            "name": "Managua",
            "code": 14191,
            "neighborhood": "Sector Sur Rotonda Jean Paul Genie",
        },
        {"name": "Managua", "code": 14192, "neighborhood": "Magnolia"},
        {
            "name": "Managua",
            "code": 14193,
            "neighborhood": "Sector Noroeste Las Colinas",
        },
        {
            "name": "Managua",
            "code": 14194,
            "neighborhood": "Sector Norte Las Colinas",
        },
        {"name": "Managua", "code": 14195, "neighborhood": "Goenz"},
        {
            "name": "Managua",
            "code": 14196,
            "neighborhood": "Sector Hotel Las Colinas",
        },
        {
            "name": "Managua",
            "code": 14197,
            "neighborhood": "Paseo Las Colinas",
        },
        {
            "name": "Managua",
            "code": 14198,
            "neighborhood": "Cumbres De Las Colinas",
        },
        {
            "name": "Managua",
            "code": 14199,
            "neighborhood": "Las Colinas",
        },
        {
            "name": "Managua",
            "code": 14201,
            "neighborhood": "Cedros De Las Colinas",
        },
        {
            "name": "Managua",
            "code": 14202,
            "neighborhood": "Lomas De Las Colinas",
        },
        {
            "name": "Managua",
            "code": 14203,
            "neighborhood": "Sector Noreste Las Colinas",
        },
        {
            "name": "Managua",
            "code": 14204,
            "neighborhood": "Naciones Unidas",
        },
        {
            "name": "Managua",
            "code": 14205,
            "neighborhood": "Villa Cuba Libre",
        },
        {
            "name": "Managua",
            "code": 14206,
            "neighborhood": "Sector Oeste Colinas De Santa Cruz",
        },
        {
            "name": "Managua",
            "code": 14207,
            "neighborhood": "Flor De Las Colinas",
        },
        {
            "name": "Managua",
            "code": 14208,
            "neighborhood": "Villa Loreto",
        },
        {
            "name": "Managua",
            "code": 14209,
            "neighborhood": "Colinas De Santa Cruz",
        },
        {
            "name": "Managua",
            "code": 14211,
            "neighborhood": "Sector Norte Colinas De Santa Cruz",
        },
        {
            "name": "Managua",
            "code": 14212,
            "neighborhood": "Sector Norte Las Jaguitas",
        },
        {
            "name": "Managua",
            "code": 14213,
            "neighborhood": "Sector Oeste Comarca Las Enramadas",
        },
        {
            "name": "Managua",
            "code": 14214,
            "neighborhood": "Cuatro Esquinas De Las Enramadas",
        },
        {
            "name": "Managua",
            "code": 14215,
            "neighborhood": "Sector Este Comarca Las Enramadas",
        },
        {
            "name": "Managua",
            "code": 14216,
            "neighborhood": "Sector Sureste Comarca Las Enramadas",
        },
        {"name": "Managua", "code": 14217, "neighborhood": "Mayales"},
        {
            "name": "Managua",
            "code": 14218,
            "neighborhood": "Sector Sur Comarca Las Enramadas",
        },
        {
            "name": "Managua",
            "code": 14219,
            "neighborhood": "Sector Norte Comarca Esquipulas",
        },
        {
            "name": "Managua",
            "code": 14221,
            "neighborhood": "Sector Este Las Cuarezma",
        },
        {
            "name": "Managua",
            "code": 14222,
            "neighborhood": "Sector Sur Comarca Las Jaguitas",
        },
        {
            "name": "Managua",
            "code": 14223,
            "neighborhood": "Sector Este Las Colinas",
        },
        {
            "name": "Managua",
            "code": 14224,
            "neighborhood": "Villa Florencia",
        },
        {
            "name": "Managua",
            "code": 14225,
            "neighborhood": "Colinas Sur",
        },
        {"name": "Managua", "code": 14226, "neighborhood": "Frascati"},
        {
            "name": "Managua",
            "code": 14227,
            "neighborhood": "Terracota 1 Y 2",
        },
        {
            "name": "Managua",
            "code": 14228,
            "neighborhood": "Estefanía",
        },
        {"name": "Managua", "code": 14229, "neighborhood": "Acoma"},
        {
            "name": "Managua",
            "code": 14231,
            "neighborhood": "Las Cuarezmas",
        },
        {
            "name": "Managua",
            "code": 14232,
            "neighborhood": "San Pablo",
        },
        {
            "name": "Managua",
            "code": 14233,
            "neighborhood": "Jardines De Las Colinas",
        },
        {
            "name": "Managua",
            "code": 14234,
            "neighborhood": "El Boquete Sector Norte Santo Domingo",
        },
        {
            "name": "Managua",
            "code": 14235,
            "neighborhood": "Mirador Sur Santo Domingo",
        },
        {
            "name": "Managua",
            "code": 14236,
            "neighborhood": "Mirador Norte Santo Domingo",
        },
        {
            "name": "Managua",
            "code": 14237,
            "neighborhood": "Lomas De Notredame",
        },
        {
            "name": "Managua",
            "code": 14238,
            "neighborhood": "Sector Norte El Mirador",
        },
        {
            "name": "Managua",
            "code": 14239,
            "neighborhood": "Castellana",
        },
        {
            "name": "Managua",
            "code": 14241,
            "neighborhood": "Alamedas Km 8 Carretera Masaya",
        },
        {
            "name": "Managua",
            "code": 14242,
            "neighborhood": "Las Lomas Camino Viejo",
        },
        {
            "name": "Managua",
            "code": 14243,
            "neighborhood": "Villa Bellini",
        },
        {
            "name": "Managua",
            "code": 14244,
            "neighborhood": "Sector Sur Cruz Del Paraíso",
        },
        {
            "name": "Managua",
            "code": 14245,
            "neighborhood": "Los Membreños",
        },
        {
            "name": "Managua",
            "code": 14246,
            "neighborhood": "Sector Norte San Isidro De La Cruz Verde",
        },
        {
            "name": "Managua",
            "code": 14247,
            "neighborhood": "Combatiente Desconocido",
        },
        {
            "name": "Managua",
            "code": 14248,
            "neighborhood": "Urbanización Gloria",
        },
        {
            "name": "Managua",
            "code": 14249,
            "neighborhood": "Sector Norte Jocote Dulce",
        },
        {
            "name": "Managua",
            "code": 14251,
            "neighborhood": "Vincent Poujardeu",
        },
        {
            "name": "Managua",
            "code": 14252,
            "neighborhood": "Miralagos",
        },
        {
            "name": "Managua",
            "code": 14253,
            "neighborhood": "Sector Sur Jocote Dulce",
        },
        {
            "name": "Managua",
            "code": 14254,
            "neighborhood": "Sector Oeste San Isidro De La Cruz Verde",
        },
        {
            "name": "Managua",
            "code": 14255,
            "neighborhood": "Sector San Isidro De La Cruz Verde",
        },
        {
            "name": "Managua",
            "code": 14256,
            "neighborhood": "Los Andes",
        },
        {
            "name": "Managua",
            "code": 14257,
            "neighborhood": "Jacarandas",
        },
        {
            "name": "Managua",
            "code": 14258,
            "neighborhood": "La Quinta",
        },
        {
            "name": "Managua",
            "code": 14259,
            "neighborhood": "Altos De Santo Domingo",
        },
        {
            "name": "Managua",
            "code": 14261,
            "neighborhood": "Anexo Las Sierritas Santo Domingo",
        },
        {
            "name": "Managua",
            "code": 14262,
            "neighborhood": "Santa Mónica",
        },
        {
            "name": "Managua",
            "code": 14263,
            "neighborhood": "Lomas De Santo Domingo",
        },
        {
            "name": "Managua",
            "code": 14264,
            "neighborhood": "Sierritas De Santo Domingo",
        },
        {
            "name": "Managua",
            "code": 14265,
            "neighborhood": "Sector Norte Sierritas De Santo Domingo",
        },
        {
            "name": "Managua",
            "code": 14266,
            "neighborhood": "Urbanización Madrid",
        },
        {
            "name": "Managua",
            "code": 14267,
            "neighborhood": "Acrópolis",
        },
        {"name": "Managua", "code": 14268, "neighborhood": "Pedregal"},
        {
            "name": "Managua",
            "code": 14269,
            "neighborhood": "Los Palmares",
        },
        {
            "name": "Managua",
            "code": 14271,
            "neighborhood": "Germán Silva",
        },
        {
            "name": "Managua",
            "code": 14272,
            "neighborhood": "16 De Marzo",
        },
        {
            "name": "Managua",
            "code": 14273,
            "neighborhood": "neighborhood Nuevo",
        },
        {
            "name": "Managua",
            "code": 14274,
            "neighborhood": "Bosques De Santa María",
        },
        {
            "name": "Managua",
            "code": 14275,
            "neighborhood": "Santa María De Los Lagos",
        },
        {
            "name": "Managua",
            "code": 14276,
            "neighborhood": "Villas Gaudi",
        },
        {
            "name": "Managua",
            "code": 14277,
            "neighborhood": "Sector Cuatro Esquinas De Esquipulas",
        },
        {
            "name": "Managua",
            "code": 14278,
            "neighborhood": "Michelangelo",
        },
        {
            "name": "Managua",
            "code": 14279,
            "neighborhood": "Entreverde",
        },
        {
            "name": "Managua",
            "code": 14281,
            "neighborhood": "Altos De Las Colinas",
        },
        {
            "name": "Managua",
            "code": 14282,
            "neighborhood": "Sector Oeste Comarca Esquipulas",
        },
        {
            "name": "Managua",
            "code": 14283,
            "neighborhood": "Sector Esquipulas",
        },
        {
            "name": "Managua",
            "code": 14284,
            "neighborhood": "Ermitas De Esquipulas",
        },
        {
            "name": "Managua",
            "code": 14285,
            "neighborhood": "Vistas De Esquipulas",
        },
        {
            "name": "Managua",
            "code": 14286,
            "neighborhood": "Sector Noreste Los Vanegas",
        },
        {
            "name": "Managua",
            "code": 14287,
            "neighborhood": "El Cenicero",
        },
        {
            "name": "Managua",
            "code": 14288,
            "neighborhood": "Los Vanegas",
        },
        {
            "name": "Managua",
            "code": 14289,
            "neighborhood": "Sector Sur Esquipulas",
        },
        {
            "name": "Managua",
            "code": 14291,
            "neighborhood": "Villanova",
        },
        {"name": "Managua", "code": 14292, "neighborhood": "Berlín"},
        {
            "name": "Managua",
            "code": 14293,
            "neighborhood": "Las Praderas",
        },
        {
            "name": "Managua",
            "code": 14294,
            "neighborhood": "Paseo Del Prado",
        },
        {
            "name": "Managua",
            "code": 14295,
            "neighborhood": "Villa Del Rosario",
        },
        {
            "name": "Managua",
            "code": 14296,
            "neighborhood": "Alamedas Santo Domingo",
        },
        {
            "name": "Managua",
            "code": 14297,
            "neighborhood": "Palma Real",
        },
        {
            "name": "Managua",
            "code": 14298,
            "neighborhood": "Sector Norte Estancia De Santo Domingo",
        },
        {
            "name": "Managua",
            "code": 14299,
            "neighborhood": "Estancia Santo Domingo",
        },
        {
            "name": "Managua",
            "code": 14301,
            "neighborhood": "Sector Sur Altos De Santo Domingo",
        },
        {
            "name": "Managua",
            "code": 14302,
            "neighborhood": "Altamonte",
        },
        {"name": "Managua", "code": 14303, "neighborhood": "Palermo"},
        {
            "name": "Managua",
            "code": 14304,
            "neighborhood": "Bosques Del Prado",
        },
        {
            "name": "Managua",
            "code": 14305,
            "neighborhood": "Sector Sur Sierritas De Santo Domingo",
        },
        {
            "name": "Managua",
            "code": 14306,
            "neighborhood": "Hadas Villas",
        },
        {
            "name": "Managua",
            "code": 14307,
            "neighborhood": "Villa De Andalucía",
        },
        {
            "name": "Managua",
            "code": 14308,
            "neighborhood": "La Arboleda Santo Domingo",
        },
        {
            "name": "Managua",
            "code": 14309,
            "neighborhood": "Bosques De Santo Domingo",
        },
        {
            "name": "Managua",
            "code": 14311,
            "neighborhood": "Quintas Del Valle",
        },
        {
            "name": "Managua",
            "code": 14312,
            "neighborhood": "El Rodeo Santo Domingo",
        },
        {
            "name": "Managua",
            "code": 14313,
            "neighborhood": "Haras De La Hoyada",
        },
        {
            "name": "Managua",
            "code": 14314,
            "neighborhood": "Condesa 1 Y 2",
        },
        {
            "name": "Managua",
            "code": 14315,
            "neighborhood": "Valle Blanco",
        },
        {
            "name": "Managua",
            "code": 14316,
            "neighborhood": "Valle Azul",
        },
        {
            "name": "Managua",
            "code": 14317,
            "neighborhood": "El Encanto 1 Y 2",
        },
        {
            "name": "Managua",
            "code": 14318,
            "neighborhood": "Sector Oeste Comarca Santo Domingo",
        },
        {
            "name": "Managua",
            "code": 14319,
            "neighborhood": "Bosques De San Isidro",
        },
        {
            "name": "Managua",
            "code": 14321,
            "neighborhood": "Sector Sur San Isidro De La Cruz Verde",
        },
        {
            "name": "Managua",
            "code": 14322,
            "neighborhood": "Monte Carlos",
        },
        {
            "name": "Managua",
            "code": 14323,
            "neighborhood": "La Esperanza Jocote Dulce",
        },
        {
            "name": "Managua",
            "code": 14324,
            "neighborhood": "Los Angeles Jocote Dulce",
        },
        {
            "name": "Managua",
            "code": 14325,
            "neighborhood": "Sector Sur Jocote Dulce",
        },
        {
            "name": "Managua",
            "code": 14326,
            "neighborhood": "Portal Del Bosque",
        },
        {
            "name": "Managua",
            "code": 14327,
            "neighborhood": "Intermezzo Del Bosque",
        },
        {
            "name": "Managua",
            "code": 14328,
            "neighborhood": "Balcones De Santo Domingo 2",
        },
        {
            "name": "Managua",
            "code": 14329,
            "neighborhood": "Balcones De Santo Domingo 1",
        },
        {
            "name": "Managua",
            "code": 14331,
            "neighborhood": "Sector Sureste San Isidro De La Cruz Verde",
        },
        {
            "name": "Managua",
            "code": 14332,
            "neighborhood": "Jardines De Santo Domingo 2",
        },
        {
            "name": "Managua",
            "code": 14333,
            "neighborhood": "Jardines De Santo Domingo 1",
        },
        {
            "name": "Managua",
            "code": 14334,
            "neighborhood": "San Antonio Sur",
        },
        {
            "name": "Managua",
            "code": 14335,
            "neighborhood": "Puertas Del Sol",
        },
        {
            "name": "Managua",
            "code": 14336,
            "neighborhood": "Sacuanjoche",
        },
        {
            "name": "Managua",
            "code": 14337,
            "neighborhood": "Valle Del Prado",
        },
        {
            "name": "Managua",
            "code": 14338,
            "neighborhood": "Campo Bello",
        },
        {
            "name": "Managua",
            "code": 14339,
            "neighborhood": "Las Palmeras",
        },
        {
            "name": "Managua",
            "code": 14341,
            "neighborhood": "Los Geranios",
        },
        {
            "name": "Managua",
            "code": 14342,
            "neighborhood": "Sector Norte Comarca San Antonio Sur",
        },
        {
            "name": "Managua",
            "code": 14343,
            "neighborhood": "Sector Sur Comarca San Antonio Sur",
        },
        {
            "name": "Managua",
            "code": 14344,
            "neighborhood": "Sector Este Comarca Candelaria Sur",
        },
        {
            "name": "Managua",
            "code": 14345,
            "neighborhood": "Sector Oeste Comarca Candelaria Sur",
        },
        {"name": "Tipitapa", "code": 15100, "neighborhood": "master"},
        {
            "name": "San Francisco Libre",
            "code": 15300,
            "neighborhood": "master",
        },
        {"name": "Mateare", "code": 15500, "neighborhood": "master"},
        {
            "name": "Ciudad Sandino",
            "code": 15700,
            "neighborhood": "master",
        },
        {
            "name": "El Crucero",
            "code": 16100,
            "neighborhood": "master",
        },
        {
            "name": "Ticuantepe",
            "code": 16300,
            "neighborhood": "master",
        },
        {
            "name": "Villa El Carmen",
            "code": 16500,
            "neighborhood": "master",
        },
        {
            "name": "San Rafael Del Sur",
            "code": 16700,
            "neighborhood": "master",
        },
    ],
    "LE": [
        {"name": "León", "code": 21000, "neighborhood": "master"},
        {
            "name": "La Paz Centro",
            "code": 22100,
            "neighborhood": "master",
        },
        {"name": "Nagarote", "code": 22200, "neighborhood": "master"},
        {
            "name": "Quezalguaque",
            "code": 22300,
            "neighborhood": "master",
        },
        {"name": "Telica", "code": 22400, "neighborhood": "master"},
        {
            "name": "Larreynaga",
            "code": 22500,
            "neighborhood": "master",
        },
        {
            "name": "El Jicaral",
            "code": 22600,
            "neighborhood": "master",
        },
        {
            "name": "Santa Rosa del Peñón",
            "code": 22700,
            "neighborhood": "master",
        },
        {"name": "El Sauce", "code": 22800, "neighborhood": "master"},
        {"name": "Achuapa", "code": 22900, "neighborhood": "master"},
    ],
    "CI": [
        {
            "name": "Chinandega",
            "code": 25000,
            "neighborhood": "master",
        },
        {
            "name": "Chichigalpa",
            "code": 26100,
            "neighborhood": "master",
        },
        {"name": "El Viejo", "code": 26200, "neighborhood": "master"},
        {
            "name": "El Realejo",
            "code": 26300,
            "neighborhood": "master",
        },
        {"name": "Corinto", "code": 26400, "neighborhood": "master"},
        {"name": "Posoltega", "code": 26500, "neighborhood": "master"},
        {
            "name": "Puerto Morazán",
            "code": 26600,
            "neighborhood": "master",
        },
        {
            "name": "Villanueva",
            "code": 26700,
            "neighborhood": "master",
        },
        {"name": "Somotillo", "code": 26800, "neighborhood": "master"},
        {
            "name": "San Francisco del Norte",
            "code": 26900,
            "neighborhood": "master",
        },
        {
            "name": "Santo Tómas del Norte",
            "code": 27100,
            "neighborhood": "master",
        },
        {
            "name": "Cinco Pinos",
            "code": 27200,
            "neighborhood": "master",
        },
        {
            "name": "San Pedro del Norte",
            "code": 27300,
            "neighborhood": "master",
        },
    ],
    "ES": [
        {"name": "Estelí", "code": 31000, "neighborhood": "master"},
        {"name": "Condega", "code": 32100, "neighborhood": "master"},
        {
            "name": "Pueblo Nuevo",
            "code": 32200,
            "neighborhood": "master",
        },
        {
            "name": "San Juan de Limay",
            "code": 32300,
            "neighborhood": "master",
        },
        {
            "name": "San Nicolás",
            "code": 32400,
            "neighborhood": "master",
        },
        {
            "name": "La Trinidad",
            "code": 32500,
            "neighborhood": "master",
        },
    ],
    "MD": [
        {"name": "Somoto", "code": 34000, "neighborhood": "master"},
        {"name": "Yalaguina", "code": 35100, "neighborhood": "master"},
        {
            "name": "Palacaguina",
            "code": 35200,
            "neighborhood": "master",
        },
        {"name": "Totogalpa", "code": 35300, "neighborhood": "master"},
        {"name": "San Lucas", "code": 35400, "neighborhood": "master"},
        {
            "name": "Las Sabanas",
            "code": 35500,
            "neighborhood": "master",
        },
        {
            "name": "San José de Cusmapa",
            "code": 35600,
            "neighborhood": "master",
        },
        {"name": "Telpaneca", "code": 35700, "neighborhood": "master"},
        {
            "name": "San Juan de Río Coco",
            "code": 35800,
            "neighborhood": "master",
        },
    ],
    "NS": [
        {"name": "Ocotal", "code": 37000, "neighborhood": "master"},
        {"name": "Mozonte", "code": 38100, "neighborhood": "master"},
        {"name": "Dipilto", "code": 38200, "neighborhood": "master"},
        {"name": "Macuelizo", "code": 38300, "neighborhood": "master"},
        {
            "name": "Ciudad Antigua",
            "code": 38400,
            "neighborhood": "master",
        },
        {
            "name": "San Fernando",
            "code": 38500,
            "neighborhood": "master",
        },
        {
            "name": "Santa María",
            "code": 38600,
            "neighborhood": "master",
        },
        {"name": "Quilalí", "code": 38700, "neighborhood": "master"},
        {"name": "El Jícaro", "code": 38800, "neighborhood": "master"},
        {"name": "Murra", "code": 38900, "neighborhood": "master"},
        {
            "name": "Wiwilí de Nueva Segovia",
            "code": 39100,
            "neighborhood": "master",
        },
        {"name": "Jalapa", "code": 39200, "neighborhood": "master"},
    ],
    "MS": [
        {"name": "Masaya", "code": 41000, "neighborhood": "master"},
        {"name": "Tisma", "code": 42100, "neighborhood": "master"},
        {"name": "Nindirí", "code": 42200, "neighborhood": "master"},
        {
            "name": "La Concepción",
            "code": 42300,
            "neighborhood": "master",
        },
        {"name": "Nandasmo", "code": 42400, "neighborhood": "master"},
        {"name": "Catarina", "code": 42500, "neighborhood": "master"},
        {"name": "Masatepe", "code": 42600, "neighborhood": "master"},
        {
            "name": "Niquinohomo",
            "code": 42700,
            "neighborhood": "master",
        },
        {
            "name": "San Juan de Oriente",
            "code": 42800,
            "neighborhood": "master",
        },
    ],
    "GR": [
        {"name": "Granada", "code": 43000, "neighborhood": "master"},
        {"name": "Diriomo", "code": 44100, "neighborhood": "master"},
        {"name": "Diriá", "code": 44200, "neighborhood": "master"},
        {"name": "Nandaime", "code": 44300, "neighborhood": "master"},
    ],
    "CA": [
        {"name": "Jinotepe", "code": 45000, "neighborhood": "master"},
        {"name": "Dolores", "code": 46100, "neighborhood": "master"},
        {
            "name": "El Rosario",
            "code": 46200,
            "neighborhood": "master",
        },
        {"name": "Diriamba", "code": 46300, "neighborhood": "master"},
        {
            "name": "San Marcos",
            "code": 46400,
            "neighborhood": "master",
        },
        {
            "name": "La Paz de Carazo",
            "code": 46500,
            "neighborhood": "master",
        },
        {
            "name": "Santa Teresa",
            "code": 46600,
            "neighborhood": "master",
        },
        {
            "name": "La Conquista",
            "code": 46700,
            "neighborhood": "master",
        },
    ],
    "RI": [
        {"name": "Rivas", "code": 47000, "neighborhood": "master"},
        {"name": "San Jorge", "code": 48100, "neighborhood": "master"},
        {
            "name": "Buenos Aires",
            "code": 48200,
            "neighborhood": "master",
        },
        {"name": "Potosí", "code": 48300, "neighborhood": "master"},
        {"name": "Belén", "code": 48400, "neighborhood": "master"},
        {"name": "Tola", "code": 48500, "neighborhood": "master"},
        {
            "name": "San Juan del Sur",
            "code": 48600,
            "neighborhood": "master",
        },
        {"name": "Moyogalpa", "code": 48700, "neighborhood": "master"},
        {
            "name": "Altagracia",
            "code": 48800,
            "neighborhood": "master",
        },
        {"name": "Cárdenas", "code": 48900, "neighborhood": "master"},
    ],
    "BO": [
        {"name": "Boaco", "code": 51000, "neighborhood": "master"},
        {"name": "Camoapa", "code": 52100, "neighborhood": "master"},
        {
            "name": "Santa Lucia",
            "code": 52200,
            "neighborhood": "master",
        },
        {"name": "Teustepe", "code": 52300, "neighborhood": "master"},
        {
            "name": "San Lorenzo",
            "code": 52400,
            "neighborhood": "master",
        },
        {
            "name": "San José de los Remates",
            "code": 52500,
            "neighborhood": "master",
        },
    ],
    "CO": [
        {"name": "Juigalpa", "code": 55000, "neighborhood": "master"},
        {"name": "Acoyapa", "code": 56100, "neighborhood": "master"},
        {
            "name": "Santo Tomás",
            "code": 56200,
            "neighborhood": "master",
        },
        {
            "name": "La Libertad",
            "code": 56300,
            "neighborhood": "master",
        },
        {
            "name": "San Francisco de Cuapa",
            "code": 56400,
            "neighborhood": "master",
        },
        {"name": "Comalapa", "code": 56500, "neighborhood": "master"},
        {
            "name": "Villa Sandino",
            "code": 56600,
            "neighborhood": "master",
        },
        {
            "name": "San Pedro de Lóvago",
            "code": 56700,
            "neighborhood": "master",
        },
        {
            "name": "Santo Domingo",
            "code": 56800,
            "neighborhood": "master",
        },
        {"name": "El Coral", "code": 56900, "neighborhood": "master"},
    ],
    "MT": [
        {"name": "Matagalpa", "code": 61000, "neighborhood": "master"},
        {"name": "San Ramón", "code": 62100, "neighborhood": "master"},
        {"name": "Sébaco", "code": 62200, "neighborhood": "master"},
        {"name": "Terrabona", "code": 62300, "neighborhood": "master"},
        {
            "name": "San Dionisio",
            "code": 62400,
            "neighborhood": "master",
        },
        {
            "name": "Esquipulas",
            "code": 62500,
            "neighborhood": "master",
        },
        {"name": "Muy Muy", "code": 62600, "neighborhood": "master"},
        {
            "name": "El Tuma La Dalia",
            "code": 62700,
            "neighborhood": "master",
        },
        {
            "name": "Ciudad Darío",
            "code": 62800,
            "neighborhood": "master",
        },
        {
            "name": "San Isidro",
            "code": 62900,
            "neighborhood": "master",
        },
        {"name": "Matiguas", "code": 63100, "neighborhood": "master"},
        {
            "name": "Río Blanco",
            "code": 63200,
            "neighborhood": "master",
        },
        {
            "name": "Rancho Grande",
            "code": 63300,
            "neighborhood": "master",
        },
    ],
    "JI": [
        {"name": "Jinotega", "code": 65000, "neighborhood": "master"},
        {
            "name": "San Rafael del Norte",
            "code": 66100,
            "neighborhood": "master",
        },
        {
            "name": "San Sebastián de Yalí",
            "code": 66200,
            "neighborhood": "master",
        },
        {
            "name": "La Concordia",
            "code": 66300,
            "neighborhood": "master",
        },
        {
            "name": "Santa María de Pantasma",
            "code": 66400,
            "neighborhood": "master",
        },
        {"name": "El Cuá", "code": 66500, "neighborhood": "master"},
        {
            "name": "San José de Bocay",
            "code": 66600,
            "neighborhood": "master",
        },
        {
            "name": "Wiwilí de Jinotega",
            "code": 66700,
            "neighborhood": "master",
        },
    ],
    "CN": [
        {
            "name": "Puerto Cabezas",
            "code": 71000,
            "neighborhood": "master",
        },
        {"name": "Waspam", "code": 72100, "neighborhood": "master"},
        {"name": "Rosita", "code": 72200, "neighborhood": "master"},
        {"name": "Bonanza", "code": 72300, "neighborhood": "master"},
        {"name": "Siuna", "code": 72400, "neighborhood": "master"},
        {
            "name": "Prinzapolka",
            "code": 72500,
            "neighborhood": "master",
        },
        {"name": "Mulukukú", "code": 72600, "neighborhood": "master"},
        {"name": "Waslala", "code": 72700, "neighborhood": "master"},
    ],
    "CS": [
        {
            "name": "Bluefields",
            "code": 81000,
            "neighborhood": "master",
        },
        {
            "name": "Corn Island",
            "code": 82100,
            "neighborhood": "master",
        },
        {"name": "Kukrahill", "code": 82200, "neighborhood": "master"},
        {"name": "El Rama", "code": 82300, "neighborhood": "master"},
        {
            "name": "Muelle de los Bueyes",
            "code": 82400,
            "neighborhood": "master",
        },
        {
            "name": "Nueva Guinea",
            "code": 82500,
            "neighborhood": "master",
        },
        {
            "name": "Laguna de Perlas",
            "code": 82600,
            "neighborhood": "master",
        },
        {
            "name": "El Tortuguero",
            "code": 82700,
            "neighborhood": "master",
        },
        {"name": "El Ayote", "code": 82800, "neighborhood": "master"},
        {
            "name": "Desembocadura de Cruz Río Grande",
            "code": 82900,
            "neighborhood": "master",
        },
        {
            "name": "Cruz del Río Grande",
            "code": 83100,
            "neighborhood": "master",
        },
        {"name": "Paiwas", "code": 83200, "neighborhood": "master"},
    ],
    "SJ": [
        {
            "name": "San Carlos",
            "code": 91000,
            "neighborhood": "master",
        },
        {
            "name": "San Miguelito",
            "code": 92100,
            "neighborhood": "master",
        },
        {
            "name": "El Castillo",
            "code": 92200,
            "neighborhood": "master",
        },
        {
            "name": "El Almendro",
            "code": 92300,
            "neighborhood": "master",
        },
        {"name": "Morrito", "code": 92400, "neighborhood": "master"},
        {
            "name": "San Juan de Nicaragua",
            "code": 92500,
            "neighborhood": "master",
        },
    ],
}



import pytest

from postalcodes_ni import (
    get_all_municipalities_by_iso,
    get_all_municipalities_by_postal,
    get_municipality_by_name,
    get_municipality_by_postal,
)
from postalcodes_ni.exceptions import ISOCodeError, PostalCodeError


def test_get_all_municipalities_by_iso():
    """ Test get all the municipalities from a department by iso code
    """
    with pytest.raises(ISOCodeError):
        get_all_municipalities_by_iso('WRONG')
    mn = get_all_municipalities_by_iso('MN')
    assert isinstance(mn, list)
    assert isinstance(mn[0], tuple)
    assert len(mn) > 0


def test_get_all_municipalities_by_postal():
    """ Test get all the municipalities from a department by postal code
    """
    with pytest.raises(PostalCodeError):
        get_all_municipalities_by_postal(666)
    mn = get_all_municipalities_by_postal(10000)
    assert isinstance(mn, list)
    assert isinstance(mn[0], tuple)
    assert len(mn) > 0


def test_get_municipality_by_name():
    """ Test get a municipality from his name
    """
    with pytest.raises(PostalCodeError):
        get_municipality_by_name('WRONG')
    # Search by neighborhood name
    mn = get_municipality_by_name('centro historico cultural')
    assert isinstance(mn, tuple)
    assert isinstance(mn[0], str)
    assert isinstance(mn[1], int)
    assert mn[1] == 11001
    assert len(mn) == 2
    # Search by municipality name
    mn = get_municipality_by_name('San Carlos')
    assert isinstance(mn, tuple)
    assert isinstance(mn[0], str)
    assert isinstance(mn[1], int)
    assert len(mn) == 2
    assert mn[1] == 91000


def test_get_municipality_by_postal():
    """ Test get a municipality from his postal code
    """
    with pytest.raises(PostalCodeError):
        get_municipality_by_postal(666)
    mn = get_municipality_by_postal(11001)
    assert isinstance(mn, tuple)
    assert isinstance(mn[0], str)
    assert isinstance(mn[1], int)
    assert len(mn) == 2


def test_all():
    """ Test that __all__ contains only names that are actually exported.
    """
    import postalcodes_ni

    missing = set(
        n
        for n in postalcodes_ni.__all__
        if getattr(postalcodes_ni, n, None) is None
    )
    assert len(missing) == 0



import unicodedata

from ._codes import _postal_codes as postal_codes
from .exceptions import ISOCodeError, PostalCodeError


def get_all_municipalities_by_iso(iso_code: str) -> list:
    """ Returns all the municipalities for a department based on the ISO code
    """
    iso_code = iso_code.upper()
    if iso_code not in postal_codes:
        raise ISOCodeError(
            f'Incorrect ISO 3166-2 code \n The code {iso_code} doesnt exists'
        )

    municipalities = [
        (m.get('name'), m.get('code')) for m in postal_codes.get(iso_code)
    ]
    return municipalities


def get_all_municipalities_by_postal(postal_code: int) -> list:
    """ Returns all the municipalities for a department based on the postal code
    """
    department_key = None
    for department, municipalities in postal_codes.items():
        for municipality in municipalities:
            if (
                municipality['code'] == postal_code
                and municipality['neighborhood'] == 'master'
            ):
                department_key = department
                break
    if department_key is None:
        raise PostalCodeError(
            f'Cant find any department with the code {postal_code}'
        )
    municipalities = [
        (m.get('name'), m.get('code'))
        for m in postal_codes.get(department_key)
    ]
    return municipalities


def get_municipality_by_name(name: str) -> tuple:
    """ Returns a single record for a municipality based on the name
    """

    def strip_accents(s):
        return ''.join(
            c
            for c in unicodedata.normalize('NFD', s)
            if unicodedata.category(c) != 'Mn'
        )

    name = strip_accents(name).title()
    department_key = None
    municipality_key = None
    for department, municipalities in postal_codes.items():
        for index, municipality in enumerate(municipalities):
            if strip_accents(municipality['name']) == name:
                department_key = department
                municipality_key = index
                break
            if strip_accents(municipality['neighborhood']) == name:
                department_key = department
                municipality_key = index
                break

    if department_key is None and municipality_key is None:
        raise PostalCodeError(
            f'Cant find any municipality with the name {name}'
        )
    municipality = postal_codes.get(department_key)[municipality_key]
    return (municipality.get('name'), municipality.get('code'))


def get_municipality_by_postal(postal_code: int) -> dict:
    """ Returns a single record for a municipality based on the postal code
    """
    for department, municipalities in postal_codes.items():
        for index, municipality in enumerate(municipalities):
            if municipality['code'] == postal_code:
                mun = postal_codes[department][index]
                return (mun.get('name'), mun.get('code'))

    raise PostalCodeError(
        f'Cant find any municipality with the code {postal_code}'
    )



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.md') as readme_file:
    readme = readme_file.read()

with open('HISTORY.md') as history_file:
    history = history_file.read()

setup_requirements = ['pytest-runner', ]
test_requirements = ['pytest', ]

setup(
    author="Oscar Cortez",
    author_email='om.cortez.2010@gmail.com',
    name='postalcodes_ni',
    version='1.1.1',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Natural Language :: Spanish',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    description="Python package for handle Nicaragua postal codes",
    license="MIT license",
    long_description=readme + '\n\n' + history,
    long_description_content_type="text/markdown",
    include_package_data=True,
    python_requires='>=3',
    keywords='postalcodes nicaragua',
    packages=find_packages(include=['postalcodes_ni']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    project_urls={
        'Documentation': 'https://postalcodes-ni.readthedocs.io',
        'Funding': 'https://donate.pypi.org',
        'Say Thanks!': 'http://saythanks.io/to/oscarmcm',
        'Source': 'https://github.com/oscarmcm/postalcodes-ni/',
        'Tracker': 'https://github.com/oscarmcm/postalcodes-ni/issues',
    },
    url='https://github.com/oscarmcm/postalcodes-ni',
    zip_safe=False,
)
